@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailstream_helper.c,v 1.17 2006/05/22 13:39:40 hoa Exp $
+ * $Id: mailstream_helper.c,v 1.18 2008/02/20 22:15:50 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -182,31 +182,31 @@ char * mailstream_read_multiline(mailstream * s, size_t size,
 
 static gboolean end_of_multiline(const char * str, gint len)
 {
-  gint index;
+  gint indx;
 
-  index = len - 1;
+  indx = len - 1;
 
-  if (str[index] != '\n')
+  if (str[indx] != '\n')
     return FALSE;
-  if (index == 0)
+  if (indx == 0)
     return FALSE;
 
-  index --;
+  indx --;
 
-  if (str[index] == '\r') {
-    index --;
-    if (index == 0)
+  if (str[indx] == '\r') {
+    indx --;
+    if (indx == 0)
       return FALSE;
   }
 
-  if (str[index] != '.')
+  if (str[indx] != '.')
     return FALSE;
-  if (index == 0)
+  if (indx == 0)
     return FALSE;
 
-  index--;
+  indx--;
 
-  if (str[index] != '\n')
+  if (str[indx] != '\n')
     return FALSE;
 
   return TRUE;
