@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailstream_socket.c,v 1.27 2007/07/12 14:42:04 smarinier Exp $
+ * $Id: mailstream_socket.c,v 1.30 2008/02/10 16:43:31 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -57,7 +57,9 @@
   to insure compatibility with Mac OS X (this is true for 10.2)
 */
 
-#ifndef _MSC_VER
+#ifdef WIN32
+#	include <win_etpan.h>
+#else
 #	include <sys/time.h>
 #	include <sys/types.h>
 #	ifdef HAVE_SYS_SELECT_H
@@ -67,6 +69,10 @@
 
 #include "mailstream_cancel.h"
 
+#if 0
+#define MAILSTREAM_SOCKET_READ
+#endif
+
 struct mailstream_socket_data {
   int fd;
   struct mailstream_cancel * cancel;
@@ -126,7 +132,7 @@ static void socket_data_free(struct mailstream_socket_data * socket_data)
 
 static void socket_data_close(struct mailstream_socket_data * socket_data)
 {
-#ifdef _MSC_VER
+#ifdef WIN32
 /* SEB */ 
   closesocket(socket_data->fd);
 #else
@@ -249,7 +255,11 @@ static ssize_t mailstream_low_socket_read(mailstream_low * s,
       return 0;
   }
   
+#ifdef MAILSTREAM_SOCKET_READ
+  return read(socket_data->fd, buf, count);
+#else
   return recv(socket_data->fd, buf, count, 0);
+#endif
 }
 
 static ssize_t mailstream_low_socket_write(mailstream_low * s,
@@ -290,7 +300,7 @@ static ssize_t mailstream_low_socket_write(mailstream_low * s,
     if (r < 0)
       return -1;
     
-    cancelled = fds_read.fd_array[r - WAIT_OBJECT_0];
+    cancelled = (fds_read.fd_array[r - WAIT_OBJECT_0] == fd);
     write_enabled = (fds_read.fd_array[r - WAIT_OBJECT_0] == event);
 #else
     FD_SET(socket_data->fd, &fds_write);
