@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_cached.c,v 1.56 2006/12/26 13:13:23 hoa Exp $
+ * $Id: imapdriver_cached.c,v 1.61 2008/02/20 22:35:47 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -53,6 +53,7 @@
 
 #include "mail.h"
 #include "imapdriver_tools.h"
+#include "imapdriver_tools_private.h"
 #include "mail_cache_db.h"
 #include "mailmessage.h"
 #include "imapdriver_cached_message.h"
@@ -149,7 +150,6 @@ static int imapdriver_cached_login_sasl(mailsession * session,
     const char * password, const char * realm);
 
 static mailsession_driver local_imap_cached_session_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sess_name */ "imap-cached",
 
   /* sess_initialize */ imapdriver_cached_initialize,
@@ -195,56 +195,7 @@ static mailsession_driver local_imap_cached_session_driver = {
 #if 0
   /* sess_search_messages */ imapdriver_cached_search_messages,
 #endif
-  /* sess_cached_login_sasl */ imapdriver_cached_login_sasl,
-
-#else
-  .sess_name = "imap-cached",
-
-  .sess_initialize = imapdriver_cached_initialize,
-  .sess_uninitialize = imapdriver_cached_uninitialize,
-
-  .sess_parameters = imapdriver_cached_parameters,
-
-  .sess_connect_stream = imapdriver_cached_connect_stream,
-  .sess_connect_path = NULL,
-  .sess_starttls = imapdriver_cached_starttls,
-  .sess_login = imapdriver_cached_login,
-  .sess_logout = imapdriver_cached_logout,
-  .sess_noop = imapdriver_cached_noop,
-
-  .sess_build_folder_name = imapdriver_cached_build_folder_name,
-  .sess_create_folder = imapdriver_cached_create_folder,
-  .sess_delete_folder = imapdriver_cached_delete_folder,
-  .sess_rename_folder = imapdriver_cached_rename_folder,
-  .sess_check_folder = imapdriver_cached_check_folder,
-  .sess_examine_folder = imapdriver_cached_examine_folder,
-  .sess_select_folder = imapdriver_cached_select_folder,
-  .sess_expunge_folder = imapdriver_cached_expunge_folder,
-  .sess_status_folder = imapdriver_cached_status_folder,
-  .sess_messages_number = imapdriver_cached_messages_number,
-  .sess_recent_number = imapdriver_cached_recent_number,
-  .sess_unseen_number = imapdriver_cached_unseen_number,
-  .sess_list_folders = imapdriver_cached_list_folders,
-  .sess_lsub_folders = imapdriver_cached_lsub_folders,
-  .sess_subscribe_folder = imapdriver_cached_subscribe_folder,
-  .sess_unsubscribe_folder = imapdriver_cached_unsubscribe_folder,
-
-  .sess_append_message = imapdriver_cached_append_message,
-  .sess_append_message_flags = imapdriver_cached_append_message_flags,
-  .sess_copy_message = imapdriver_cached_copy_message,
-  .sess_move_message = NULL,
-
-  .sess_get_messages_list = imapdriver_cached_get_messages_list,
-  .sess_get_envelopes_list = imapdriver_cached_get_envelopes_list,
-  .sess_remove_message = imapdriver_cached_remove_message,
-#if 0
-  .sess_search_messages = imapdriver_cached_search_messages,
-#endif
-
-  .sess_get_message = imapdriver_cached_get_message,
-  .sess_get_message_by_uid = imapdriver_cached_get_message_by_uid,
-  .sess_login_sasl = imapdriver_cached_login_sasl,
-#endif
+  /* sess_cached_login_sasl */ imapdriver_cached_login_sasl
 };
 
 mailsession_driver * imap_cached_session_driver =
@@ -944,7 +895,7 @@ static int boostrap_cache(mailsession * session)
   
   r = mail_cache_db_open_lock(filename, &cache_db);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto free_mmapstr;
   }
   
@@ -992,7 +943,7 @@ static int boostrap_cache(mailsession * session)
   for(iter = chash_begin(keys_uid) ; iter != NULL ; iter = chash_next(keys_uid, iter)) {
     chashdatum key;
     uint32_t uidvalidity;
-    uint32_t index;
+    uint32_t indx;
     char * uid;
     char * p1, * p2;
     struct uid_cache_item * cache_item;
@@ -1007,7 +958,7 @@ static int boostrap_cache(mailsession * session)
     data->imap_uidvalidity = uidvalidity;
     
     p1++;
-    index = strtoul(p1, &p2, 10);
+    indx = strtoul(p1, &p2, 10);
     if (p2 == p1 || * p2 != '\0')
       continue;
     
@@ -1017,7 +968,7 @@ static int boostrap_cache(mailsession * session)
       goto free_keys_uid;
     }
     
-    cache_item->uid = index;
+    cache_item->uid = indx;
     cache_item->size = 0;
     
     carray_add(data->imap_uid_list, cache_item, NULL);
@@ -1100,9 +1051,6 @@ static int imapdriver_cached_get_messages_list(mailsession * session,
     
     msg = carray_get(env_list->msg_tab, i);
     if (msg->msg_index < uid_max + 1) {
-      mailmessage * msg;
-      
-      msg = carray_get(env_list->msg_tab, i);
       mailmessage_free(msg);
       carray_delete(env_list->msg_tab, i);
     }
@@ -1247,7 +1195,7 @@ static int get_flags_list(mailsession * session,
     return MAIL_NO_ERROR;
   }
 
-  r = msg_list_to_imap_set(msg_list, &set);
+  r = imap_msg_list_to_imap_set(msg_list, &set);
   if (r != MAIL_NO_ERROR) {
     clist_foreach(msg_list, (clist_func) free, NULL);
     clist_free(msg_list);
@@ -1406,7 +1354,7 @@ imapdriver_cached_get_envelopes_list(mailsession * session,
 
   r = mail_cache_db_open_lock(filename, &cache_db);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto free_mmapstr;
   }
 
@@ -1458,7 +1406,7 @@ imapdriver_cached_get_envelopes_list(mailsession * session,
 
   r = mail_cache_db_open_lock(filename, &cache_db);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto free_mmapstr;
   }
 
