@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_message.c,v 1.24 2006/06/26 11:50:26 hoa Exp $
+ * $Id: imapdriver_message.c,v 1.26 2008/02/17 13:13:26 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -40,6 +40,7 @@
 #include "imapdriver_message.h"
 
 #include "imapdriver_tools.h"
+#include "imapdriver_tools_private.h"
 #include "imapdriver.h"
 #include "imapdriver_types.h"
 #include "mailimap.h"
@@ -101,7 +102,6 @@ static void imap_flush(mailmessage * msg_info);
 static void imap_check(mailmessage * msg_info);
 
 static mailmessage_driver local_imap_message_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* msg_name */ "imap",
   
   /* msg_initialize */ imap_initialize,
@@ -123,31 +123,7 @@ static mailmessage_driver local_imap_message_driver = {
   /* msg_fetch_section_body */ imap_fetch_section_body,
   /* msg_fetch_envelope */ imap_fetch_envelope,
 
-  /* msg_get_flags */ imap_get_flags,
-#else
-  .msg_name = "imap",
-  
-  .msg_initialize = imap_initialize,
-  .msg_uninitialize = NULL,
-
-  .msg_flush = imap_flush,
-  .msg_check = imap_check,
-  
-  .msg_fetch_result_free = imap_fetch_result_free,
-
-  .msg_fetch = imap_fetch,
-  .msg_fetch_header = imap_fetch_header,
-  .msg_fetch_body = imap_fetch_body,
-  .msg_fetch_size = imap_fetch_size,
-  .msg_get_bodystructure = imap_get_bodystructure,
-  .msg_fetch_section = imap_fetch_section,
-  .msg_fetch_section_header = imap_fetch_section_header,
-  .msg_fetch_section_mime = imap_fetch_section_mime,
-  .msg_fetch_section_body = imap_fetch_section_body,
-  .msg_fetch_envelope = imap_fetch_envelope,
-
-  .msg_get_flags = imap_get_flags,
-#endif
+  /* msg_get_flags */ imap_get_flags
 };
 
 mailmessage_driver * imap_message_driver = &local_imap_message_driver;
@@ -939,7 +915,7 @@ static int imap_fetch_section(mailmessage * msg_info,
   if (r != MAILIMF_NO_ERROR)
     return maildriver_imf_error_to_mail_error(r);
 
-  r = section_to_imap_section(part, IMAP_SECTION_MESSAGE, &section);
+  r = imap_section_to_imap_section(part, IMAP_SECTION_MESSAGE, &section);
   mailmime_section_free(part);
   if (r != MAIL_NO_ERROR)
     return r;
@@ -989,7 +965,7 @@ static int imap_fetch_section_header(mailmessage * msg_info,
   if (r != MAILIMF_NO_ERROR)
     return maildriver_imf_error_to_mail_error(r);
 
-  r = section_to_imap_section(part, IMAP_SECTION_HEADER, &section);
+  r = imap_section_to_imap_section(part, IMAP_SECTION_HEADER, &section);
   mailmime_section_free(part);
   if (r != MAIL_NO_ERROR)
     return r;
@@ -1041,7 +1017,7 @@ static int imap_fetch_section_mime(mailmessage * msg_info,
   if (r != MAILIMF_NO_ERROR)
     return maildriver_imf_error_to_mail_error(r);
 
-  r = section_to_imap_section(part, IMAP_SECTION_MIME, &section);
+  r = imap_section_to_imap_section(part, IMAP_SECTION_MIME, &section);
   mailmime_section_free(part);
   if (r != MAIL_NO_ERROR)
     return MAIL_ERROR_MEMORY;
@@ -1094,7 +1070,7 @@ static int imap_fetch_section_body(mailmessage * msg_info,
   if (r != MAILIMF_NO_ERROR)
     return maildriver_imf_error_to_mail_error(r);
 
-  r = section_to_imap_section(part, IMAP_SECTION_BODY, &section);
+  r = imap_section_to_imap_section(part, IMAP_SECTION_BODY, &section);
   mailmime_section_free(part);
   if (r != MAIL_NO_ERROR)
     return MAIL_ERROR_MEMORY;
