@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_tools.c,v 1.31 2008/03/16 13:39:34 hoa Exp $
+ * $Id: imapdriver_tools.c,v 1.36 2009/12/19 00:56:15 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -958,7 +958,7 @@ imap_body_fields_to_mime_fields(struct mailimap_body_fields * body_fields,
   return MAIL_NO_ERROR;
 
  free_list:
-  clist_foreach(list, (clist_func) mailmime_fields_free, NULL);
+  clist_foreach(list, (clist_func) mailmime_field_free, NULL);
   clist_free(list);
  err:
   return res;
@@ -1230,9 +1230,16 @@ imap_body_type_msg_to_body(struct mailimap_body_type_msg *
   int res;
   uint32_t mime_size;
   
-  r = imap_body_fields_to_mime_fields(imap_type_msg->bd_fields,
-      body_ext_1part->bd_disposition, body_ext_1part->bd_language,
-      &mime_fields, &mime_size);
+  if (body_ext_1part != NULL) {
+  	r = imap_body_fields_to_mime_fields(imap_type_msg->bd_fields,
+      	body_ext_1part->bd_disposition, body_ext_1part->bd_language,
+      	&mime_fields, &mime_size);
+  }
+  else {
+  	r = imap_body_fields_to_mime_fields(imap_type_msg->bd_fields,
+      	NULL, NULL,
+      	&mime_fields, &mime_size);
+  }
   if (r != MAIL_NO_ERROR) {
     res = r;
     goto err;
@@ -1446,7 +1453,7 @@ imap_body_type_mpart_to_body(struct mailimap_body_type_mpart *
 
   if (body == NULL) {
     res = MAIL_ERROR_MEMORY;
-    goto err;
+    goto free_list;
   }
 
   * result = body;
@@ -1530,6 +1537,14 @@ int imap_address_to_mailbox(struct mailimap_address * imap_addr,
       goto free_name;
     }
   }
+  else if (imap_addr->ad_mailbox_name == NULL) {
+    // fix by Gabor Cselle, (http://gaborcselle.com/), reported 8/16/2009
+    addr = strdup(imap_addr->ad_host_name); 
+    if (addr == NULL) {
+      res = MAIL_ERROR_MEMORY;
+      goto free_name;
+    }
+  }
   else {
     addr = malloc(strlen(imap_addr->ad_mailbox_name) +
         strlen(imap_addr->ad_host_name) + 2);
