@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapstorage.h,v 1.12 2006/06/02 15:44:29 smarinier Exp $
+ * $Id: imapstorage.h,v 1.13 2007/06/30 12:58:21 hoa Exp $
  */
 
 #ifndef IMAPSTORAGE_H
@@ -97,6 +97,20 @@ int imap_mailstorage_init_sasl(struct mailstorage * storage,
     const char * password, const char * realm,
     int imap_cached, const char * imap_cache_directory);
 
+LIBETPAN_EXPORT
+int imap_mailstorage_init_sasl_with_local_address(struct mailstorage * storage,
+    const char * imap_servername, uint16_t imap_port,
+    const char * imap_local_address, uint16_t imap_local_port,
+    const char * imap_command,
+    int imap_connection_type,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm,
+    int imap_cached, const char * imap_cache_directory);
+
 #ifdef __cplusplus
 }
 #endif
