@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mboxdriver_message.c,v 1.19 2006/06/26 11:50:26 hoa Exp $
+ * $Id: mboxdriver_message.c,v 1.20 2008/02/17 13:13:26 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -70,7 +70,6 @@ static int mbox_fetch_header(mailmessage * msg_info,
 			     size_t * result_len);
 
 static mailmessage_driver local_mbox_message_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* msg_name */ "mbox",
 
   /* msg_initialize */ mbox_initialize,
@@ -92,31 +91,7 @@ static mailmessage_driver local_mbox_message_driver = {
   /* msg_fetch_section_body */ mailmessage_generic_fetch_section_body,
   /* msg_fetch_envelope */ mailmessage_generic_fetch_envelope,
 
-  /* msg_get_flags */ NULL,
-#else
-  .msg_name = "mbox",
-
-  .msg_initialize = mbox_initialize,
-  .msg_uninitialize = mailmessage_generic_uninitialize,
-
-  .msg_flush = mailmessage_generic_flush,
-  .msg_check = NULL,
-
-  .msg_fetch_result_free = mailmessage_generic_fetch_result_free,
-
-  .msg_fetch = mailmessage_generic_fetch,
-  .msg_fetch_header = mbox_fetch_header,
-  .msg_fetch_body = mailmessage_generic_fetch_body,
-  .msg_fetch_size = mbox_fetch_size,
-  .msg_get_bodystructure = mailmessage_generic_get_bodystructure,
-  .msg_fetch_section = mailmessage_generic_fetch_section,
-  .msg_fetch_section_header = mailmessage_generic_fetch_section_header,
-  .msg_fetch_section_mime = mailmessage_generic_fetch_section_mime,
-  .msg_fetch_section_body = mailmessage_generic_fetch_section_body,
-  .msg_fetch_envelope = mailmessage_generic_fetch_envelope,
-
-  .msg_get_flags = NULL,
-#endif
+  /* msg_get_flags */ NULL
 };
 
 mailmessage_driver * mbox_message_driver = &local_mbox_message_driver;
