@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mhdriver_cached.c,v 1.50 2008/02/20 22:15:50 hoa Exp $
+ * $Id: mhdriver_cached.c,v 1.52 2010/04/05 14:43:48 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -287,7 +287,11 @@ static int write_max_uid_value(mailsession * session)
     goto free_mmapstr;
   }
 
-  fwrite(mmapstr->str, 1, mmapstr->len, f);
+  r = fwrite(mmapstr->str, 1, mmapstr->len, f);
+  if ((size_t) r != mmapstr->len) {
+    res = MAIL_ERROR_FILE;
+    goto free_mmapstr;
+  }
 
   mmap_string_free(mmapstr);
   fclose(f);
