@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mhstorage.c,v 1.13 2006/06/26 11:50:26 hoa Exp $
+ * $Id: mhstorage.c,v 1.14 2008/02/17 13:13:26 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -54,17 +54,10 @@ static int mh_mailstorage_get_folder_session(struct mailstorage * storage,
 static void mh_mailstorage_uninitialize(struct mailstorage * storage);
 
 static mailstorage_driver mh_mailstorage_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sto_name               */ "mh",
   /* sto_connect            */ mh_mailstorage_connect,
   /* sto_get_folder_session */ mh_mailstorage_get_folder_session,
-  /* sto_uninitialize       */ mh_mailstorage_uninitialize,
-#else
-  .sto_name               = "mh",
-  .sto_connect            = mh_mailstorage_connect,
-  .sto_get_folder_session = mh_mailstorage_get_folder_session,
-  .sto_uninitialize       = mh_mailstorage_uninitialize,
-#endif
+  /* sto_uninitialize       */ mh_mailstorage_uninitialize
 };
 
 LIBETPAN_EXPORT
