@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: nntpdriver.c,v 1.52 2008/02/17 13:13:27 hoa Exp $
+ * $Id: nntpdriver.c,v 1.53 2009/08/29 18:36:31 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -447,6 +447,8 @@ static int nntpdriver_list_folders(mailsession * session, const char * mb,
     case NEWSNNTP_WARNING_REQUEST_AUTHORIZATION_USERNAME:
       r = nntpdriver_authenticate_user(session);
       if (r != MAIL_NO_ERROR) {
+	      if (new_mb != NULL)
+		free(new_mb);
 	res = r;
 	goto err;
       }
@@ -455,6 +457,8 @@ static int nntpdriver_list_folders(mailsession * session, const char * mb,
     case NEWSNNTP_WARNING_REQUEST_AUTHORIZATION_PASSWORD:
       r = nntpdriver_authenticate_password(session);
       if (r != MAIL_NO_ERROR) {
+	      if (new_mb != NULL)
+		free(new_mb);
 	res = r;
 	goto err;
       }
