@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: pop3driver_cached_message.c,v 1.20 2006/06/26 11:50:27 hoa Exp $
+ * $Id: pop3driver_cached_message.c,v 1.22 2008/02/17 13:13:27 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -75,7 +75,6 @@ static int pop3_get_flags(mailmessage * msg_info,
 static void pop3_uninitialize(mailmessage * msg_info);
 
 static mailmessage_driver local_pop3_cached_message_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* msg_name */ "pop3-cached",
 
   /* msg_initialize */ pop3_initialize,
@@ -97,31 +96,7 @@ static mailmessage_driver local_pop3_cached_message_driver = {
   /* msg_fetch_section_body */ mailmessage_generic_fetch_section_body,
   /* msg_fetch_envelope */ mailmessage_generic_fetch_envelope,
 
-  /* msg_get_flags */ pop3_get_flags,
-#else
-  .msg_name = "pop3-cached",
-
-  .msg_initialize = pop3_initialize,
-  .msg_uninitialize = pop3_uninitialize,
-
-  .msg_flush = pop3_flush,
-  .msg_check = pop3_check,
-
-  .msg_fetch_result_free = mailmessage_generic_fetch_result_free,
-
-  .msg_fetch = mailmessage_generic_fetch,
-  .msg_fetch_header = pop3_fetch_header,
-  .msg_fetch_body = mailmessage_generic_fetch_body,
-  .msg_fetch_size = pop3_fetch_size,
-  .msg_get_bodystructure = mailmessage_generic_get_bodystructure,
-  .msg_fetch_section = mailmessage_generic_fetch_section,
-  .msg_fetch_section_header = mailmessage_generic_fetch_section_header,
-  .msg_fetch_section_mime = mailmessage_generic_fetch_section_mime,
-  .msg_fetch_section_body = mailmessage_generic_fetch_section_body,
-  .msg_fetch_envelope = mailmessage_generic_fetch_envelope,
-
-  .msg_get_flags = pop3_get_flags,
-#endif
+  /* msg_get_flags */ pop3_get_flags
 };
 
 mailmessage_driver * pop3_cached_message_driver =
@@ -345,7 +320,7 @@ static int pop3_get_flags(mailmessage * msg_info,
     
     r = mail_cache_db_open_lock(filename_flags, &cache_db_flags);
     if (r < 0) {
-      res = MAIL_ERROR_MEMORY;
+      res = MAIL_ERROR_FILE;
       goto err;
     }
     
