@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildriver_tools.c,v 1.34 2006/06/07 15:10:01 smarinier Exp $
+ * $Id: maildriver_tools.c,v 1.36 2008/02/20 22:15:51 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -44,8 +44,8 @@
 #include <stdlib.h>
 #include <ctype.h>
 #include <string.h>
-#ifdef _MSC_VER
-#include "win_etpan.h"
+#ifdef WIN32
+#	include "win_etpan.h"
 #else
 #	include <dirent.h>
 #endif
@@ -68,59 +68,7 @@ maildriver_generic_get_envelopes_list(mailsession * session,
 {
   int r;
   unsigned i;
-#if 0
-  uint32_t j;
-  uint32_t last_msg;
 
-  last_msg = 0;
-#endif
-
-#if 0
-  j = 0;
-  i = 0;
-  while (i < env_list->tab->len) {
-    mailmessage * msg;
-    uint32_t index;
-    
-    msg = carray_get(env_list->tab, i);
-
-    index = msg->index;
-
-    if (msg->fields == NULL) {
-      struct mailimf_fields * fields;
-
-      r = mailmessage_fetch_envelope(msg, &fields);
-      if (r != MAIL_NO_ERROR) {
-	/* do nothing */
-      }
-      else {
-	msg->fields = fields;
-	
-	carray_set(env_list->tab, j, msg);
-	
-	j ++;
-	last_msg = i + 1;
-      }
-      mailmessage_flush(msg);
-    }
-    else {
-      j ++;
-      last_msg = i + 1;
-    }
-
-    i ++;
-  }
-
-  for(i = last_msg ; i < env_list->tab->len ; i ++) {
-    mailmessage_free(carray_get(env_list->tab, i));
-    carray_set(env_list->tab, i, NULL);
-  }
-
-  r = carray_set_size(env_list->tab, j);
-  if (r < 0)
-    return MAIL_ERROR_MEMORY;
-#endif
-  
   for(i = 0 ; i < carray_count(env_list->msg_tab) ; i ++) {
     mailmessage * msg;
     
@@ -414,7 +362,7 @@ int maildriver_generic_search_messages(mailsession * session, char * charset,
     info = carray_get(env_list->tab, i);
 
     if (!header) {
-      r = mailsession_fetch_message(session, info->index, &message, &length);
+      r = mailsession_fetch_message(session, info->indx, &message, &length);
       if (r != MAIL_NO_ERROR) {
 	res = r;
 	goto free_list;
@@ -434,7 +382,7 @@ int maildriver_generic_search_messages(mailsession * session, char * charset,
       size_t cur_token;
       size_t header_len;
 
-      r = mailsession_fetch_message_header(session, info->index, &msg_header,
+      r = mailsession_fetch_message_header(session, info->indx, &msg_header,
 					   &header_len);
       if (r != MAIL_NO_ERROR) {
 	res = r;
@@ -453,7 +401,7 @@ int maildriver_generic_search_messages(mailsession * session, char * charset,
       mailsession_fetch_result_free(session, msg_header);
     }
 
-    r = mailsession_get_message_flags(session, info->index, &flags);
+    r = mailsession_get_message_flags(session, info->indx, &flags);
     if (r != MAIL_NO_ERROR) {
       res = r;
       goto free_list;
@@ -471,7 +419,7 @@ int maildriver_generic_search_messages(mailsession * session, char * charset,
 	goto free_list;
       }
 
-      * pnum = info->index;
+      * pnum = info->indx;
 
       r = clist_append(list, pnum);
       if (r < 0) {
