@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailfolder.c,v 1.4 2005/05/19 17:11:55 hoa Exp $
+ * $Id: mailfolder.c,v 1.6 2006/05/22 13:39:40 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailfolder.h"
 
 #include <string.h>
@@ -40,21 +44,25 @@
 #include "maildriver.h"
 #include "mailstorage.h"
 
+LIBETPAN_EXPORT
 int mailfolder_noop(struct mailfolder * folder)
 {
   return mailsession_noop(folder->fld_session);
 }
 
+LIBETPAN_EXPORT
 int mailfolder_check(struct mailfolder * folder)
 {
   return mailsession_check_folder(folder->fld_session);
 }
 
+LIBETPAN_EXPORT
 int mailfolder_expunge(struct mailfolder * folder)
 {
   return mailsession_expunge_folder(folder->fld_session);
 }
 
+LIBETPAN_EXPORT
 int mailfolder_status(struct mailfolder * folder,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen)
@@ -64,12 +72,14 @@ int mailfolder_status(struct mailfolder * folder,
       result_recent, result_unseen);
 }
 
+LIBETPAN_EXPORT
 int mailfolder_append_message(struct mailfolder * folder,
     char * message, size_t size)
 {
   return mailsession_append_message(folder->fld_session, message, size);
 }
 
+LIBETPAN_EXPORT
 int mailfolder_append_message_flags(struct mailfolder * folder,
     char * message, size_t size, struct mail_flags * flags)
 {
@@ -77,6 +87,7 @@ int mailfolder_append_message_flags(struct mailfolder * folder,
       size, flags);
 }
 
+LIBETPAN_EXPORT
 int mailfolder_get_messages_list(struct mailfolder * folder,
     struct mailmessage_list ** result)
 {
@@ -114,12 +125,14 @@ int mailfolder_get_messages_list(struct mailfolder * folder,
   return MAIL_NO_ERROR;
 }
 
+LIBETPAN_EXPORT
 int mailfolder_get_envelopes_list(struct mailfolder * folder,
     struct mailmessage_list * result)
 {
   return mailsession_get_envelopes_list(folder->fld_session, result);
 }
 
+LIBETPAN_EXPORT
 int mailfolder_get_message(struct mailfolder * folder,
     uint32_t num, mailmessage ** result)
 {
@@ -137,6 +150,7 @@ int mailfolder_get_message(struct mailfolder * folder,
   return MAIL_NO_ERROR;
 }
 
+LIBETPAN_EXPORT
 int mailfolder_get_message_by_uid(struct mailfolder * folder,
     const char * uid, mailmessage ** result)
 {
