@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailthread.c,v 1.30 2007/01/18 09:15:01 hoa Exp $
+ * $Id: mailthread.c,v 1.32 2008/02/20 22:35:48 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -51,7 +51,7 @@
 #include "clist.h"
 #include "mailmessage.h"
 #include "timeutils.h"
-#ifdef _MSC_VER
+#ifdef WIN32
 #	include "win_etpan.h"
 #endif
 
@@ -1019,7 +1019,6 @@ mail_build_thread_references(char * default_from,
       chashdatum key;
       chashdatum data;
       char * base_subject;
-      int r;
 
       env_tree = carray_get(rootlist, cur);
 
@@ -1135,7 +1134,6 @@ mail_build_thread_references(char * default_from,
       struct mailmessage_tree * env_tree;
       chashdatum key;
       chashdatum data;
-      int r;
       struct mailmessage_tree * main_tree;
       unsigned int * main_cur;
 
