@@ -30,16 +30,15 @@
  */
 
 /*
- * $Id: mailengine.c,v 1.10 2005/12/16 02:19:15 hoa Exp $
+ * $Id: mailengine.c,v 1.11 2006/05/22 13:39:40 hoa Exp $
  */
 
-#include "mailengine.h"
-
-#ifndef CONFIG_H
-#define CONFIG_H
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
 #endif
 
+#include "mailengine.h"
+
 #include "mailfolder.h"
 #include "maildriver.h"
 #include "imapdriver_cached.h"
