@@ -44,6 +44,7 @@ int mailimap_idle(mailimap * session)
   size_t indx;
   struct mailimap_continue_req * cont_req;
   struct mailimap_response * response;
+  clist * resp_data_list;
   
   session->imap_idle_timestamp = time(NULL);
   
@@ -67,6 +68,22 @@ int mailimap_idle(mailimap * session)
   
   indx = 0;
 
+  r = mailimap_struct_multiple_parse(session->imap_stream,
+					session->imap_stream_buffer,
+					&indx,
+					&resp_data_list,
+					(mailimap_struct_parser *)
+					mailimap_response_data_parse,
+					(mailimap_struct_destructor *)
+					mailimap_response_data_free,
+					session->imap_progr_rate, session->imap_progr_fun);
+  if ((r != MAILIMAP_NO_ERROR) && (r != MAILIMAP_ERROR_PARSE))
+    return r;
+  if (r == MAILIMAP_NO_ERROR) {
+    clist_foreach(resp_data_list,
+	  (clist_func) mailimap_response_data_free, NULL);
+  }
+
   r = mailimap_continue_req_parse(session->imap_stream,
       session->imap_stream_buffer,
       &indx, &cont_req,
@@ -81,7 +98,7 @@ int mailimap_idle(mailimap * session)
       return r;
     mailimap_response_free(response);
     
-    return MAILIMAP_ERROR_EXTENSION;
+    return MAILIMAP_ERROR_PARSE;
   }
   
   return MAILIMAP_NO_ERROR;
