@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap_keywords.c,v 1.12 2006/06/26 11:50:27 hoa Exp $
+ * $Id: mailimap_keywords.c,v 1.13 2008/02/20 22:15:51 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -53,14 +53,14 @@ struct mailimap_token_value {
 
 int mailimap_token_case_insensitive_parse(mailstream * fd,
 					  MMAPString * buffer,
-					  size_t * index,
+					  size_t * indx,
 					  const char * token)
 {
   int len;
   size_t cur_token;
   int r;
 
-  cur_token = * index;
+  cur_token = * indx;
   len = strlen(token);
 
 #ifdef UNSTRICT_SYNTAX
@@ -71,7 +71,7 @@ int mailimap_token_case_insensitive_parse(mailstream * fd,
 
   if (strncasecmp(buffer->str + cur_token, token, len) == 0) {
     cur_token += len;
-    * index = cur_token;
+    * indx = cur_token;
     return MAILIMAP_NO_ERROR;
   }
   else
@@ -85,15 +85,15 @@ static int is_space_or_tab(char ch)
 }
 
 int mailimap_char_parse(mailstream * fd, MMAPString * buffer,
-			size_t * index, char token)
+			size_t * indx, char token)
 {
   int cur_token;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   if (buffer->str[cur_token] == token) {
     cur_token ++;
-    * index = cur_token;
+    * indx = cur_token;
     return MAILIMAP_NO_ERROR;
   }
   else
@@ -101,49 +101,49 @@ int mailimap_char_parse(mailstream * fd, MMAPString * buffer,
 }
 
 int mailimap_space_parse(mailstream * fd, MMAPString * buffer,
-			 size_t * index)
+			 size_t * indx)
 {
 #ifdef UNSTRICT_SYNTAX
 
   /* can accept unstrict syntax */
   size_t cur_token;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   while (is_space_or_tab(* (buffer->str + cur_token)))
     cur_token ++;
 
-  if (cur_token == * index)
+  if (cur_token == * indx)
     return MAILIMAP_ERROR_PARSE;
 
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMAP_NO_ERROR;
 
 #else
-  return mailimap_char_parse(fd, buffer, index, ' ');
+  return mailimap_char_parse(fd, buffer, indx, ' ');
 #endif
 }
 
 
 
-#define mailimap_get_token_str(index, tab) \
-           mailimap_get_token_str_size(index, tab, \
+#define mailimap_get_token_str(indx, tab) \
+           mailimap_get_token_str_size(indx, tab, \
            sizeof(tab) / sizeof(struct mailimap_token_value))
 
-#define mailimap_get_token_value(fd, buffer, index, tab) \
-           mailimap_get_token_value_size(fd, buffer, index, tab, \
+#define mailimap_get_token_value(fd, buffer, indx, tab) \
+           mailimap_get_token_value_size(fd, buffer, indx, tab, \
            sizeof(tab) / sizeof(struct mailimap_token_value))
 
 
-static const char * mailimap_get_token_str_size(int index,
+static const char * mailimap_get_token_str_size(int indx,
 					  struct mailimap_token_value * tab,
 					  size_t size)
 {
   size_t i;
 
   for(i = 0 ; i < size ; i++)
-    if (index == tab[i].value)
+    if (indx == tab[i].value)
       return tab[i].str;
   
   return NULL;
@@ -152,7 +152,7 @@ static const char * mailimap_get_token_str_size(int index,
 
 
 static int mailimap_get_token_value_size(mailstream * fd, MMAPString * buffer,
-					 size_t * index,
+					 size_t * indx,
 					 struct mailimap_token_value * tab,
 					 size_t size)
 {
@@ -161,13 +161,13 @@ static int mailimap_get_token_value_size(mailstream * fd, MMAPString * buffer,
 
 #ifdef UNSTRICT_SYNTAX
   /* can accept unstrict syntax */
-  r = mailimap_space_parse(fd, buffer, index);
+  r = mailimap_space_parse(fd, buffer, indx);
   if ((r != MAILIMAP_NO_ERROR) && (r != MAILIMAP_ERROR_PARSE))
     return r;
 #endif
 
   for(i = 0 ; i < size ; i++) {
-    r = mailimap_token_case_insensitive_parse(fd, buffer, index, tab[i].str);
+    r = mailimap_token_case_insensitive_parse(fd, buffer, indx, tab[i].str);
     if (r == MAILIMAP_NO_ERROR)
       return tab[i].value;
   }
@@ -185,24 +185,24 @@ static struct mailimap_token_value status_att_tab[] = {
 };
 
 int mailimap_status_att_get_token_value(mailstream * fd, MMAPString * buffer,
-					size_t * index)
+					size_t * indx)
 {
   int r;
 
 #ifdef UNSTRICT_SYNTAX
   /* can accept unstrict syntax */
-  r = mailimap_space_parse(fd, buffer, index);
+  r = mailimap_space_parse(fd, buffer, indx);
   if ((r != MAILIMAP_NO_ERROR) && (r != MAILIMAP_ERROR_PARSE))
     return r;
 #endif
-  return mailimap_get_token_value(fd, buffer, index,
+  return mailimap_get_token_value(fd, buffer, indx,
 				  status_att_tab);
 }
 
 
-const char * mailimap_status_att_get_token_str(size_t index)
+const char * mailimap_status_att_get_token_str(size_t indx)
 {
-  return mailimap_get_token_str(index, status_att_tab);
+  return mailimap_get_token_str(indx, status_att_tab);
 }
 
 static struct mailimap_token_value month_tab[] = {
@@ -221,15 +221,15 @@ static struct mailimap_token_value month_tab[] = {
 };
 
 int mailimap_month_get_token_value(mailstream * fd, MMAPString * buffer,
-				   size_t * index)
+				   size_t * indx)
 {
-  return mailimap_get_token_value(fd, buffer, index, month_tab);
+  return mailimap_get_token_value(fd, buffer, indx, month_tab);
 }
 
 
-const char * mailimap_month_get_token_str(size_t index)
+const char * mailimap_month_get_token_str(size_t indx)
 {
-  return mailimap_get_token_str(index, month_tab);
+  return mailimap_get_token_str(indx, month_tab);
 }
 
 
@@ -245,16 +245,16 @@ static struct mailimap_token_value mailimap_flag_tab[] = {
 };
 
 int mailimap_flag_get_token_value(mailstream * fd, MMAPString * buffer,
-				  size_t * index)
+				  size_t * indx)
 {
-  return mailimap_get_token_value(fd, buffer, index,
+  return mailimap_get_token_value(fd, buffer, indx,
 				  mailimap_flag_tab);
 }
 
 
-const char * mailimap_flag_get_token_str(size_t index)
+const char * mailimap_flag_get_token_str(size_t indx)
 {
-  return mailimap_get_token_str(index, mailimap_flag_tab);
+  return mailimap_get_token_str(indx, mailimap_flag_tab);
 }
 
 
@@ -269,9 +269,9 @@ static struct mailimap_token_value encoding_tab[] = {
 };
 
 int mailimap_encoding_get_token_value(mailstream * fd, MMAPString * buffer,
-				      size_t * index)
+				      size_t * indx)
 {
-  return mailimap_get_token_value(fd, buffer, index, encoding_tab);
+  return mailimap_get_token_value(fd, buffer, indx, encoding_tab);
 }
 
 static struct mailimap_token_value mbx_list_sflag_tab[] = {
@@ -282,9 +282,9 @@ static struct mailimap_token_value mbx_list_sflag_tab[] = {
 
 int mailimap_mbx_list_sflag_get_token_value(mailstream * fd,
 					    MMAPString * buffer,
-					    size_t * index)
+					    size_t * indx)
 {
-  return mailimap_get_token_value(fd, buffer, index, mbx_list_sflag_tab);
+  return mailimap_get_token_value(fd, buffer, indx, mbx_list_sflag_tab);
 }
 
 static struct mailimap_token_value media_basic_tab[] = {
@@ -296,9 +296,9 @@ static struct mailimap_token_value media_basic_tab[] = {
 };
 
 int mailimap_media_basic_get_token_value(mailstream * fd, MMAPString * buffer,
-					 size_t * index)
+					 size_t * indx)
 {
-  return mailimap_get_token_value(fd, buffer, index, media_basic_tab);
+  return mailimap_get_token_value(fd, buffer, indx, media_basic_tab);
 }
 
 static struct mailimap_token_value resp_cond_state_tab[] = {
@@ -309,9 +309,9 @@ static struct mailimap_token_value resp_cond_state_tab[] = {
 
 int mailimap_resp_cond_state_get_token_value(mailstream * fd,
 					     MMAPString * buffer,
-					     size_t * index)
+					     size_t * indx)
 {
-  return mailimap_get_token_value(fd, buffer, index, resp_cond_state_tab);
+  return mailimap_get_token_value(fd, buffer, indx, resp_cond_state_tab);
 }
 
 static struct mailimap_token_value resp_text_code_1_tab[] = {
@@ -324,9 +324,9 @@ static struct mailimap_token_value resp_text_code_1_tab[] = {
 
 int mailimap_resp_text_code_1_get_token_value(mailstream * fd,
 					      MMAPString * buffer,
-					      size_t * index)
+					      size_t * indx)
 {
-  return mailimap_get_token_value(fd, buffer, index, resp_text_code_1_tab);
+  return mailimap_get_token_value(fd, buffer, indx, resp_text_code_1_tab);
 }
 
 static struct mailimap_token_value resp_text_code_2_tab[] = {
@@ -337,9 +337,9 @@ static struct mailimap_token_value resp_text_code_2_tab[] = {
 
 int mailimap_resp_text_code_2_get_token_value(mailstream * fd,
 					      MMAPString * buffer,
-					      size_t * index)
+					      size_t * indx)
 {
-  return mailimap_get_token_value(fd, buffer, index, resp_text_code_2_tab);
+  return mailimap_get_token_value(fd, buffer, indx, resp_text_code_2_tab);
 }
 
 static struct mailimap_token_value section_msgtext_tab[] = {
@@ -351,7 +351,7 @@ static struct mailimap_token_value section_msgtext_tab[] = {
 
 int mailimap_section_msgtext_get_token_value(mailstream * fd,
 					     MMAPString * buffer,
-					     size_t * index)
+					     size_t * indx)
 {
-  return mailimap_get_token_value(fd, buffer, index, section_msgtext_tab);
+  return mailimap_get_token_value(fd, buffer, indx, section_msgtext_tab);
 }
