@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap_parser.h,v 1.11 2008/02/20 22:15:52 hoa Exp $
+ * $Id: mailimap_parser.h,v 1.14 2010/01/03 22:45:24 hoa Exp $
  */
 
 #ifndef MAILIMAP_PARSER_H
@@ -62,6 +62,13 @@ mailimap_continue_req_parse(mailstream * fd, MMAPString * buffer,
 			    size_t progr_rate,
 			    progress_function * progr_fun);
 
+int
+mailimap_response_data_parse(mailstream * fd, MMAPString * buffer,
+			     size_t * indx,
+			     struct mailimap_response_data ** result,
+			     size_t progr_rate,
+			     progress_function * progr_fun);
+
 typedef int mailimap_struct_parser(mailstream * fd, MMAPString * buffer,
 				   size_t * indx, void * result,
 				   size_t progr_rate,
@@ -101,6 +108,11 @@ int mailimap_oparenth_parse(mailstream * fd, MMAPString * buffer,
 int mailimap_cparenth_parse(mailstream * fd, MMAPString * buffer,
 				   size_t * indx);
 
+int mailimap_atom_parse(mailstream * fd, MMAPString * buffer,
+			size_t * indx, char ** result,
+			size_t progr_rate,
+			progress_function * progr_fun);
+
 int
 mailimap_astring_parse(mailstream * fd, MMAPString * buffer,
 		       size_t * indx,
@@ -108,6 +120,10 @@ mailimap_astring_parse(mailstream * fd, MMAPString * buffer,
 		       size_t progr_rate,
 		       progress_function * progr_fun);
 
+int
+mailimap_number_parse(mailstream * fd, MMAPString * buffer,
+		      size_t * indx, uint32_t * result);
+
 int
 mailimap_nz_number_parse(mailstream * fd, MMAPString * buffer,
 			 size_t * indx, uint32_t * result);
@@ -127,6 +143,14 @@ int mailimap_uniqueid_parse(mailstream * fd, MMAPString * buffer,
 int mailimap_colon_parse(mailstream * fd, MMAPString * buffer,
     size_t * indx);
 
+int
+mailimap_struct_multiple_parse(mailstream * fd, MMAPString * buffer,
+			       size_t * indx, clist ** result,
+			       mailimap_struct_parser * parser,
+			       mailimap_struct_destructor * destructor,
+			       size_t progr_rate,
+			       progress_function * progr_fun);
+
 #ifdef __cplusplus
 }
 #endif
