@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap_sender.h,v 1.13 2006/04/25 07:41:50 lemma Exp $
+ * $Id: mailimap_sender.h,v 1.14 2006/10/20 00:13:30 hoa Exp $
  */
 
 #ifndef MAILIMAP_SENDER_H
@@ -176,6 +176,9 @@ int mailimap_mailbox_send(mailstream * fd, const char * mb);
 
 int mailimap_astring_send(mailstream * fd, const char * astring);
 
+int mailimap_set_send(mailstream * fd,
+    struct mailimap_set * set);
+
 #ifdef __cplusplus
 }
 #endif
