@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap_types.c,v 1.26 2006/10/25 23:10:59 hoa Exp $
+ * $Id: mailimap_types.c,v 1.28 2009/09/06 22:20:26 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1550,8 +1550,10 @@ mailimap_message_data_new(uint32_t mdt_number, int mdt_type,
   struct mailimap_message_data * msg_data;
 
   msg_data = malloc(sizeof(* msg_data));
-  if (msg_data == NULL)
+  if (msg_data == NULL) {
     free(msg_data);
+    return NULL;
+  }
 
   msg_data->mdt_number = mdt_number;
   msg_data->mdt_type = mdt_type;
@@ -2053,7 +2055,7 @@ mailimap_response_fatal_new(struct mailimap_resp_cond_bye * rsp_bye)
 
   resp_fatal->rsp_bye = rsp_bye;
 
-  return NULL;
+  return resp_fatal;
 }
 
 void mailimap_response_fatal_free(struct mailimap_response_fatal * resp_fatal)
