@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap_types_helper.h,v 1.11 2004/11/21 21:53:37 hoa Exp $
+ * $Id: mailimap_types_helper.h,v 1.12 2008/02/20 22:15:52 hoa Exp $
  */
 
 #ifndef MAILIMAP_TYPES_HELPER_H
@@ -56,10 +56,10 @@ extern "C" {
 
 /*
   this function creates a new set item with a single message
-  given by index
+  given by indx
 */
 
-struct mailimap_set_item * mailimap_set_item_new_single(uint32_t index);
+struct mailimap_set_item * mailimap_set_item_new_single(uint32_t indx);
 
 /*
   this function creates a new set with one set item
@@ -78,7 +78,7 @@ struct mailimap_set * mailimap_set_new_interval(uint32_t first, uint32_t last);
   this function creates a set with a single message
 */
 
-struct mailimap_set * mailimap_set_new_single(uint32_t index);
+struct mailimap_set * mailimap_set_new_single(uint32_t indx);
 
 /*
   this function creates an empty set of messages
@@ -114,7 +114,7 @@ int mailimap_set_add_interval(struct mailimap_set * set,
 */
 
 int mailimap_set_add_single(struct mailimap_set * set,
-			 uint32_t index);
+			 uint32_t indx);
 
 /*
   this function creates a mailimap_section structure to request
