@@ -49,17 +49,10 @@ mailimap_uidplus_free(struct mailimap_extension_data * ext_data);
 
 LIBETPAN_EXPORT
 struct mailimap_extension_api mailimap_extension_uidplus = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* name */          "UIDPLUS",
   /* extension_id */  MAILIMAP_EXTENSION_UIDPLUS,
   /* parser */        mailimap_uidplus_parse,
-  /* free */          mailimap_uidplus_free,
-#else
-  .name             = "UIDPLUS",
-  .extension_id     = MAILIMAP_EXTENSION_UIDPLUS,
-  .parser           = mailimap_uidplus_parse,
-  .free             = mailimap_uidplus_free,
-#endif
+  /* free */          mailimap_uidplus_free
 };
 
 LIBETPAN_EXPORT
