@@ -13,7 +13,7 @@ extern "C" {
 #include "mailimap_extension_types.h"
 
 int mailimap_uidplus_parse(int calling_parser, mailstream * fd,
-    MMAPString * buffer, size_t * index,
+    MMAPString * buffer, size_t * indx,
     struct mailimap_extension_data ** result,
     size_t progr_rate,
     progress_function * progr_fun);
