@@ -1280,7 +1280,7 @@ char * mailimf_get_message_id(void)
 
   gethostname(name, MAX_MESSAGE_ID);
   snprintf(id, MAX_MESSAGE_ID, "etPan.%lx.%lx.%x@%s",
-	   now, value, getpid(), name);
+	   (long) now, value, getpid(), name);
 
   return strdup(id);
 }
@@ -1322,6 +1322,10 @@ void mailimf_single_fields_init(struct mailimf_single_fields * single_fields,
 
   memset(single_fields, 0, sizeof(struct mailimf_single_fields));
 
+  if (fields == NULL) {
+    return;
+  }
+
   cur = clist_begin(fields->fld_list);
   while (cur != NULL) {
     struct mailimf_field * field;
