@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildir.c,v 1.17 2006/10/12 08:00:21 hoa Exp $
+ * $Id: maildir.c,v 1.19 2008/02/17 13:13:29 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -42,7 +42,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
-#ifdef _MSC_VER
+#ifdef WIN32
 #	include "win_etpan.h"
 #else
 #	include <unistd.h>
@@ -113,7 +113,7 @@ void maildir_free(struct maildir * md)
 #define MAX_TRY_ALLOC 32
 
 static char * maildir_get_new_message_filename(struct maildir * md,
-    char * tmpfile)
+    char * tmp_file)
 {
   char filename[PATH_MAX];
   char basename[PATH_MAX];
@@ -131,18 +131,18 @@ static char * maildir_get_new_message_filename(struct maildir * md,
     snprintf(filename, sizeof(filename), "%s/tmp/%s",
         md->mdir_path, basename);
     
-    if (link(tmpfile, filename) == 0) {
+    if (link(tmp_file, filename) == 0) {
       got_file = 1;
-      unlink(tmpfile);
+      unlink(tmp_file);
     }
     else if (errno == EXDEV) {
-      unlink(tmpfile);
+      unlink(tmp_file);
       return NULL;
     }
     else if (errno == EPERM) {
-      r = rename(tmpfile, filename);
+      r = rename(tmp_file, filename);
       if (r < 0) {
-        unlink(tmpfile);
+        unlink(tmp_file);
         return NULL;
       }
       got_file = 1;
@@ -254,7 +254,7 @@ static struct maildir_msg * msg_new(char * filename, int new_msg)
   return NULL;
 }
 
-static void maildir_flush(struct maildir * md, int msg_new)
+static void maildir_flush(struct maildir * md, int new_msg)
 {
   unsigned int i;
   
@@ -265,7 +265,7 @@ static void maildir_flush(struct maildir * md, int msg_new)
 
     msg = carray_get(md->mdir_msg_list, i);
     
-    if (msg_new) {
+    if (new_msg) {
       delete = 0;
       if ((msg->msg_flags & MAILDIR_FLAG_NEW) != 0)
         delete = 1;
