@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailmh.c,v 1.31 2005/06/13 07:24:07 hoa Exp $
+ * $Id: mailmh.c,v 1.35 2008/02/20 22:15:52 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailmh.h"
 
 /*
@@ -50,7 +54,7 @@ sys     0m0.110s
 
 */
 
-#ifdef _MSC_VER
+#ifdef WIN32
 #	include "win_etpan.h"
 #else
 #	include <dirent.h>
@@ -91,7 +95,7 @@ void mailmh_free(struct mailmh * f)
 
 
 
-struct mailmh_msg_info * mailmh_msg_info_new(uint32_t index, size_t size,
+struct mailmh_msg_info * mailmh_msg_info_new(uint32_t indx, size_t size,
 					     time_t mtime)
 {
   struct mailmh_msg_info * msg_info;
@@ -99,7 +103,7 @@ struct mailmh_msg_info * mailmh_msg_info_new(uint32_t index, size_t size,
   msg_info = malloc(sizeof(* msg_info));
   if (msg_info == NULL)
     return NULL;
-  msg_info->msg_index = index;
+  msg_info->msg_index = indx;
   msg_info->msg_size = size;
   msg_info->msg_mtime = mtime;
 
@@ -151,11 +155,6 @@ struct mailmh_folder * mailmh_folder_new(struct mailmh_folder * parent,
   if (folder->fl_msgs_tab == NULL)
     goto free_name;
 
-#if 0
-  folder->fl_msgs_hash = cinthash_new(128);
-  if (folder->fl_msgs_hash == NULL)
-    goto free_msgs_tab;
-#endif
   folder->fl_msgs_hash = chash_new(CHASH_DEFAULTSIZE, CHASH_COPYKEY);
   if (folder->fl_msgs_hash == NULL)
     goto free_msgs_tab;
@@ -177,9 +176,6 @@ struct mailmh_folder * mailmh_folder_new(struct mailmh_folder * parent,
  free_subfolders_tab:
   carray_free(folder->fl_subfolders_tab);
  free_msgs_hash:
-#if 0
-  cinthash_free(folder->fl_msgs_hash);
-#endif
   chash_free(folder->fl_msgs_hash);
  free_msgs_tab:
   carray_free(folder->fl_msgs_tab);
@@ -216,9 +212,6 @@ void mailmh_folder_free(struct mailmh_folder * folder)
   }
   carray_free(folder->fl_msgs_tab);
   chash_free(folder->fl_msgs_hash);
-#if 0
-  cinthash_free(folder->fl_msgs_hash);
-#endif
   
   free(folder->fl_filename);
   free(folder->fl_name);
@@ -240,23 +233,6 @@ struct mailmh_folder * mailmh_folder_find(struct mailmh_folder * root,
   if (strcmp(root->fl_filename, filename) == 0)
     return root;
 
-#if 0
-  r = mailmh_folder_update(root);
-  if (r != MAILMH_NO_ERROR)
-    return NULL;
-#endif
-
-#if 0
-  for(i = 0 ; i < root->fl_subfolders_tab->len ; i++) {
-    struct mailmh_folder * subfolder;
-
-    subfolder = carray_get(root->fl_subfolders_tab, i);
-    if (subfolder != NULL)
-      if (strncmp(subfolder->fl_filename, filename,
-		  strlen(subfolder->fl_filename)) == 0)
-	return mailmh_folder_find(subfolder, filename);
-  }
-#endif
   strncpy(pathname, filename, PATH_MAX);
   pathname[PATH_MAX - 1] = 0;
   start = pathname + strlen(root->fl_filename) + 1;
@@ -296,9 +272,6 @@ int mailmh_folder_update(struct mailmh_folder * folder)
   int res;
   int r;
   uint32_t max_index;
-#if 0
-  int add_folder;
-#endif
   unsigned int i;
 
   if (stat(folder->fl_filename, &buf) == -1) {
@@ -321,13 +294,6 @@ int mailmh_folder_update(struct mailmh_folder * folder)
 
   max_index = 0;
 
-#if 0
-  if (folder->fl_subfolders_tab->len == 0)
-    add_folder = 1;
-  else
-    add_folder = 0;
-#endif
-
   /* clear the message list */
 
   for(i = 0 ; i < carray_count(folder->fl_msgs_tab) ; i ++) {
@@ -338,9 +304,6 @@ int mailmh_folder_update(struct mailmh_folder * folder)
     if (msg_info == NULL)
       continue;
 
-#if 0
-    cinthash_remove(folder->fl_msgs_hash, msg_info->msg_index);
-#endif
     key.data = &msg_info->msg_index;
     key.len = sizeof(msg_info->msg_index);
     chash_delete(folder->fl_msgs_hash, &key, NULL);
@@ -351,7 +314,7 @@ int mailmh_folder_update(struct mailmh_folder * folder)
   carray_set_size(folder->fl_msgs_tab, 0);
 
   do {
-    uint32_t index;
+    uint32_t indx;
 
     ent = readdir(d);
 
@@ -364,14 +327,14 @@ int mailmh_folder_update(struct mailmh_folder * folder)
 	continue;
 
       if (S_ISREG(buf.st_mode)) {
-	index = strtoul(ent->d_name, NULL, 10);
-	if (index != 0) {
+	indx = strtoul(ent->d_name, NULL, 10);
+	if (indx != 0) {
 	  struct mailmh_msg_info * msg_info;
 	  unsigned int array_index;
           chashdatum key;
           chashdatum data;
 
-	  msg_info = mailmh_msg_info_new(index, buf.st_size, buf.st_mtime);
+	  msg_info = mailmh_msg_info_new(indx, buf.st_size, buf.st_mtime);
 	  if (msg_info == NULL) {
 	    res = MAILMH_ERROR_MEMORY;
 	    goto closedir;
@@ -385,12 +348,9 @@ int mailmh_folder_update(struct mailmh_folder * folder)
 	  }
 	  msg_info->msg_array_index = array_index;
 
-	  if (index > max_index)
-	    max_index = index;
+	  if (indx > max_index)
+	    max_index = indx;
 
-#if 0
-	  r = cinthash_add(folder->fl_msgs_hash, msg_info->msg_index, msg_info);
-#endif
           key.data = &msg_info->msg_index;
           key.len = sizeof(msg_info->msg_index);
           data.data = msg_info;
@@ -674,24 +634,18 @@ static int mailmh_folder_alloc_msg(struct mailmh_folder * folder,
 }
 
 int mailmh_folder_get_message_filename(struct mailmh_folder * folder,
-				       uint32_t index, char ** result)
+				       uint32_t indx, char ** result)
 {
   char * filename;
   int len;
 
-#if 0
-  r = mailmh_folder_update(folder);
-  if (r != MAILMH_NO_ERROR)
-    return r;
-#endif
-
   len = strlen(folder->fl_filename) + 20;
   filename = malloc(len);
   if (filename == NULL)
     return MAILMH_ERROR_MEMORY;
 
   snprintf(filename, len, "%s%c%lu", folder->fl_filename, MAIL_DIR_SEPARATOR,
-	   (unsigned long) index);
+	   (unsigned long) indx);
 
   * result = filename;
 
@@ -700,19 +654,13 @@ int mailmh_folder_get_message_filename(struct mailmh_folder * folder,
 
 
 int mailmh_folder_get_message_fd(struct mailmh_folder * folder,
-				 uint32_t index, int flags, int * result)
+				 uint32_t indx, int flags, int * result)
 {
   char * filename;
   int fd;
   int r;
 
-#if 0
-  r = mailmh_folder_update(folder);
-  if (r != MAILMH_NO_ERROR)
-    return r;
-#endif
-
-  r = mailmh_folder_get_message_filename(folder, index, &filename);
+  r = mailmh_folder_get_message_filename(folder, indx, &filename);
   if (r != MAILMH_NO_ERROR)
     return r;
 
@@ -727,13 +675,13 @@ int mailmh_folder_get_message_fd(struct mailmh_folder * folder,
 }
 
 int mailmh_folder_get_message_size(struct mailmh_folder * folder,
-				   uint32_t index, size_t * result)
+				   uint32_t indx, size_t * result)
 {
   int r;
   char * filename;
   struct stat buf;
 
-  r = mailmh_folder_get_message_filename(folder, index, &filename);
+  r = mailmh_folder_get_message_filename(folder, indx, &filename);
   if (r != MAILMH_NO_ERROR)
     return r;
 
@@ -757,7 +705,7 @@ int mailmh_folder_add_message_uid(struct mailmh_folder * folder,
   size_t left;
   ssize_t res;
   struct mailmh_msg_info * msg_info;
-  uint32_t index;
+  uint32_t indx;
   int error;
   int r;
   unsigned int array_index;
@@ -765,14 +713,6 @@ int mailmh_folder_add_message_uid(struct mailmh_folder * folder,
   chashdatum key;
   chashdatum data;
 
-#if 0  
-  r = mailmh_folder_update(folder);
-  if (r != MAILMH_NO_ERROR) {
-    error = r;
-    goto err;
-  }
-#endif
-
   namesize = strlen(folder->fl_filename) + 20;
   tmpname = malloc(namesize);
   snprintf(tmpname, namesize, "%s%ctmpXXXXXX",
@@ -802,7 +742,7 @@ int mailmh_folder_add_message_uid(struct mailmh_folder * folder,
     goto free;
   }
 
-  r = mailmh_folder_alloc_msg(folder, tmpname, &index);
+  r = mailmh_folder_alloc_msg(folder, tmpname, &indx);
   if (r != MAILMH_NO_ERROR) {
     unlink(tmpname);
     error = MAILMH_ERROR_COULD_NOT_ALLOC_MSG;
@@ -810,32 +750,29 @@ int mailmh_folder_add_message_uid(struct mailmh_folder * folder,
   }
   free(tmpname);
 
-  msg_info = mailmh_msg_info_new(index, size, buf.st_mtime);
+  msg_info = mailmh_msg_info_new(indx, size, buf.st_mtime);
   if (msg_info == NULL) {
-    mailmh_folder_remove_message(folder, index);
+    mailmh_folder_remove_message(folder, indx);
     error = MAILMH_ERROR_MEMORY;
     goto err;
   }
   
   r = carray_add(folder->fl_msgs_tab, msg_info, &array_index);
   if (r < 0) {
-    mailmh_folder_remove_message(folder, index);
+    mailmh_folder_remove_message(folder, indx);
     mailmh_msg_info_free(msg_info);
     error = MAILMH_ERROR_MEMORY;
     goto err;
   }
   msg_info->msg_array_index = array_index;
 
-#if 0
-  r = cinthash_add(folder->fl_msgs_hash, index, msg_info);
-#endif
-  key.data = &index;
-  key.len = sizeof(index);
+  key.data = &indx;
+  key.len = sizeof(indx);
   data.data = msg_info;
   data.len = 0;
   
   if (pindex != NULL)
-    * pindex = index;
+    * pindex = indx;
   
   r = chash_set(folder->fl_msgs_hash, &key, &data, NULL);
   if (r < 0) {
@@ -866,17 +803,11 @@ int mailmh_folder_add_message_file_uid(struct mailmh_folder * folder,
   struct stat buf;
   int r;
 
-#if 0
-  r = mailmh_folder_update(folder);
-  if (r != MAILMH_NO_ERROR)
-    return r;
-#endif
-
   if (fstat(fd, &buf) == -1)
     return MAILMH_ERROR_FILE;
 
   message = mmap(NULL, buf.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
-  if (message == MAP_FAILED)
+  if (message == (const char *)MAP_FAILED)
     return MAILMH_ERROR_FILE;
 
   r = mailmh_folder_add_message_uid(folder, message, buf.st_size, pindex);
@@ -893,7 +824,7 @@ int mailmh_folder_add_message_file(struct mailmh_folder * folder,
 }
 
 int mailmh_folder_remove_message(struct mailmh_folder * folder,
-				 uint32_t index)
+				 uint32_t indx)
 {
   char * filename;
   struct mailmh_msg_info * msg_info;
@@ -902,15 +833,7 @@ int mailmh_folder_remove_message(struct mailmh_folder * folder,
   chashdatum key;
   chashdatum data;
 
-#if 0  
-  r = mailmh_folder_update(folder);
-  if (r != MAILMH_NO_ERROR) {
-    res = r;
-    goto err;
-  }
-#endif
-
-  r = mailmh_folder_get_message_filename(folder, index, &filename);
+  r = mailmh_folder_get_message_filename(folder, indx, &filename);
   if (filename == NULL) {
     res = r;
     goto err;
@@ -921,19 +844,13 @@ int mailmh_folder_remove_message(struct mailmh_folder * folder,
     goto free;
   }
 
-  key.data = &index;
-  key.len = sizeof(index);
+  key.data = &indx;
+  key.len = sizeof(indx);
   r = chash_get(folder->fl_msgs_hash, &key, &data);
-#if 0
-  msg_info = cinthash_find(folder->fl_msgs_hash, index);
-#endif
   if (r == 0) {
     msg_info = data.data;
 
     carray_delete_fast(folder->fl_msgs_tab, msg_info->msg_array_index);
-#if 0
-    cinthash_remove(folder->fl_msgs_hash, index);
-#endif
     chash_delete(folder->fl_msgs_hash, &key, NULL);
   }
 
@@ -948,33 +865,24 @@ int mailmh_folder_remove_message(struct mailmh_folder * folder,
 
 int mailmh_folder_move_message(struct mailmh_folder * dest_folder,
 			       struct mailmh_folder * src_folder,
-			       uint32_t index)
+			       uint32_t indx)
 {
   int fd;
   char * filename;
   int r;
 
-#if 0
-  r = mailmh_folder_update(dest_folder);
-  if (r != MAILMH_NO_ERROR)
-    return r;
-  r = mailmh_folder_update(src_folder);
-  if (r != MAILMH_NO_ERROR)
-    return r;
-#endif
-
   /* move on the same filesystem */
-  r = mailmh_folder_get_message_filename(src_folder, index, &filename);
+  r = mailmh_folder_get_message_filename(src_folder, indx, &filename);
   if (r != MAILMH_NO_ERROR)
     return r;
 
-  r = mailmh_folder_alloc_msg(dest_folder, filename, &index);
+  r = mailmh_folder_alloc_msg(dest_folder, filename, &indx);
   free(filename);
   if (r == MAILMH_NO_ERROR)
     return MAILMH_NO_ERROR;
 
   /* move on the different filesystems */
-  r = mailmh_folder_get_message_fd(src_folder, index, O_RDONLY, &fd);
+  r = mailmh_folder_get_message_fd(src_folder, indx, O_RDONLY, &fd);
   if (r != MAILMH_NO_ERROR)
     return r;
 
@@ -986,7 +894,7 @@ int mailmh_folder_move_message(struct mailmh_folder * dest_folder,
 
   close(fd);
 
-  r = mailmh_folder_remove_message(src_folder, index);
+  r = mailmh_folder_remove_message(src_folder, indx);
 
   return MAILMH_NO_ERROR;
 }
