@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailmime.c,v 1.26 2005/06/01 16:04:46 hoa Exp $
+ * $Id: mailmime.c,v 1.28 2008/02/20 22:15:52 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailmime.h"
 
 /*
@@ -68,48 +72,48 @@
 #endif
 
 static int mailmime_attribute_parse(const char * message, size_t length,
-				    size_t * index,
+				    size_t * indx,
 				    char ** result);
 static int
 mailmime_composite_type_parse(const char * message, size_t length,
-			      size_t * index,
+			      size_t * indx,
 			      struct mailmime_composite_type ** result);
 
 static int is_text(char ch);
 
 static int
 mailmime_discrete_type_parse(const char * message, size_t length,
-			     size_t * index,
+			     size_t * indx,
 			     struct mailmime_discrete_type ** result);
 
 static int mailmime_mechanism_parse(const char * message, size_t length,
-				    size_t * index,
+				    size_t * indx,
 				    struct mailmime_mechanism ** result);
 
 static int mailmime_subtype_parse(const char * message, size_t length,
-				  size_t * index, char ** result);
+				  size_t * indx, char ** result);
 
 static int is_token(char ch);
 
 static int mailmime_token_parse(const char * message, size_t length,
-				size_t * index,
+				size_t * indx,
 				char ** token);
 
 static int is_tspecials(char ch);
 
 static int mailmime_type_parse(const char * message, size_t length,
-			       size_t * index,
+			       size_t * indx,
 			       struct mailmime_type ** result);
 
 /*
 int mailmime_version_parse(const char * message, guint32 length,
-				guint32 * index,
+				guint32 * indx,
 			        guint32 * result);
 */
 
 /*
 static gboolean mailmime_x_token_parse(gconst char * message, guint32 length,
-				       guint32 * index,
+				       guint32 * indx,
 				       gchar ** result);
 */
 
@@ -122,10 +126,10 @@ x  attribute := token
 */
 
 static int mailmime_attribute_parse(const char * message, size_t length,
-				    size_t * index,
+				    size_t * indx,
 				    char ** result)
 {
-  return mailmime_token_parse(message, length, index, result);
+  return mailmime_token_parse(message, length, indx, result);
 }
 
 /*
@@ -134,7 +138,7 @@ x  composite-type := "message" / "multipart" / extension-token
 
 static int
 mailmime_composite_type_parse(const char * message, size_t length,
-			      size_t * index,
+			      size_t * indx,
 			      struct mailmime_composite_type ** result)
 {
   char * extension_token;
@@ -144,7 +148,7 @@ mailmime_composite_type_parse(const char * message, size_t length,
   int r;
   int res;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   extension_token = NULL;
 
@@ -174,7 +178,7 @@ mailmime_composite_type_parse(const char * message, size_t length,
   }
 
   * result = ct;
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMF_NO_ERROR;
 
@@ -194,7 +198,7 @@ x  content := "Content-Type" ":" type "/" subtype
 
 LIBETPAN_EXPORT
 int mailmime_content_parse(const char * message, size_t length,
-			   size_t * index,
+			   size_t * indx,
 			   struct mailmime_content ** result)
 {
   size_t cur_token;
@@ -205,7 +209,7 @@ int mailmime_content_parse(const char * message, size_t length,
   int r;
   int res;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   mailimf_cfws_parse(message, length, &cur_token);
 
@@ -292,7 +296,7 @@ int mailmime_content_parse(const char * message, size_t length,
   }
  
   * result = content;
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMF_NO_ERROR;
  
@@ -326,11 +330,11 @@ static int is_text(char ch)
 
 LIBETPAN_EXPORT
 int mailmime_description_parse(const char * message, size_t length,
-			       size_t * index,
+			       size_t * indx,
 			       char ** result)
 {
   return mailimf_custom_string_parse(message, length,
-				     index, result,
+				     indx, result,
 				     is_text);
 }
 
@@ -343,7 +347,7 @@ x  discrete-type := "text" / "image" / "audio" / "video" /
 
 static int
 mailmime_discrete_type_parse(const char * message, size_t length,
-			     size_t * index,
+			     size_t * indx,
 			     struct mailmime_discrete_type ** result)
 {
   char * extension;
@@ -353,7 +357,7 @@ mailmime_discrete_type_parse(const char * message, size_t length,
   int r;
   int res;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   extension = NULL;
 
@@ -411,7 +415,7 @@ mailmime_discrete_type_parse(const char * message, size_t length,
   }
 
   * result = discrete_type;
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMF_NO_ERROR;
 
@@ -427,10 +431,10 @@ x  encoding := "Content-Transfer-Encoding" ":" mechanism
 
 LIBETPAN_EXPORT
 int mailmime_encoding_parse(const char * message, size_t length,
-			    size_t * index,
+			    size_t * indx,
 			    struct mailmime_mechanism ** result)
 {
-  return mailmime_mechanism_parse(message, length, index, result);
+  return mailmime_mechanism_parse(message, length, indx, result);
 }
 
 /*
@@ -636,9 +640,9 @@ x  extension-token := ietf-token / x-token
 LIBETPAN_EXPORT
 int
 mailmime_extension_token_parse(const char * message, size_t length,
-			       size_t * index, char ** result)
+			       size_t * indx, char ** result)
 {
-  return mailmime_token_parse(message, length, index, result);
+  return mailmime_token_parse(message, length, indx, result);
 }
 
 /*
@@ -667,9 +671,9 @@ x  id := "Content-ID" ":" msg-id
 
 LIBETPAN_EXPORT
 int mailmime_id_parse(const char * message, size_t length,
-		      size_t * index, char ** result)
+		      size_t * indx, char ** result)
 {
-  return mailimf_msg_id_parse(message, length, index, result);
+  return mailimf_msg_id_parse(message, length, indx, result);
 }
 
 /*
@@ -679,7 +683,7 @@ x  mechanism := "7bit" / "8bit" / "binary" /
 */
 
 static int mailmime_mechanism_parse(const char * message, size_t length,
-				    size_t * index,
+				    size_t * indx,
 				    struct mailmime_mechanism ** result)
 {
   char * token;
@@ -689,7 +693,7 @@ static int mailmime_mechanism_parse(const char * message, size_t length,
   int r;
   int res;
 
-  cur_token = * index;
+  cur_token = * indx;
   
   type = MAILMIME_MECHANISM_ERROR; /* XXX - removes a gcc warning */
 
@@ -745,7 +749,7 @@ static int mailmime_mechanism_parse(const char * message, size_t length,
   }
 
   * result = mechanism;
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMF_NO_ERROR;
 
@@ -925,7 +929,7 @@ x  parameter := attribute "=" value
 
 LIBETPAN_EXPORT
 int mailmime_parameter_parse(const char * message, size_t length,
-			     size_t * index,
+			     size_t * indx,
 			     struct mailmime_parameter ** result)
 {
   char * attribute;
@@ -935,7 +939,7 @@ int mailmime_parameter_parse(const char * message, size_t length,
   int r;
   int res;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   r = mailmime_attribute_parse(message, length, &cur_token, &attribute);
   if (r != MAILIMF_NO_ERROR) {
@@ -968,7 +972,7 @@ int mailmime_parameter_parse(const char * message, size_t length,
   }
 
   * result = parameter;
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMF_NO_ERROR;
 
@@ -1019,9 +1023,9 @@ x  subtype := extension-token / iana-token
 */
 
 static int mailmime_subtype_parse(const char * message, size_t length,
-				  size_t * index, char ** result)
+				  size_t * indx, char ** result)
 {
-  return mailmime_extension_token_parse(message, length, index, result);
+  return mailmime_extension_token_parse(message, length, indx, result);
 }
 
 /*
@@ -1047,11 +1051,11 @@ static int is_token(char ch)
 
 
 static int mailmime_token_parse(const char * message, size_t length,
-				size_t * index,
+				size_t * indx,
 				char ** token)
 {
   return mailimf_custom_string_parse(message, length,
-				     index, token,
+				     indx, token,
 				     is_token);
 }
 
@@ -1074,13 +1078,13 @@ enum {
 };
 
 gboolean mailmime_transport_padding_parse(gconst char * message, guint32 length,
-					  guint32 * index)
+					  guint32 * indx)
 {
   guint32 cur_token;
   gint state;
   guint32 last_valid_pos;
 
-  cur_token = * index;
+  cur_token = * indx;
   
   if (cur_token >= length)
     return FALSE;
@@ -1137,7 +1141,7 @@ gboolean mailmime_transport_padding_parse(gconst char * message, guint32 length,
     }
   }
 
-  * index = cur_token;
+  * indx = cur_token;
 
   return TRUE;
 }
@@ -1180,7 +1184,7 @@ x  type := discrete-type / composite-type
 */
 
 static int mailmime_type_parse(const char * message, size_t length,
-			       size_t * index,
+			       size_t * indx,
 			       struct mailmime_type ** result)
 {
   struct mailmime_discrete_type * discrete_type;
@@ -1191,7 +1195,7 @@ static int mailmime_type_parse(const char * message, size_t length,
   int res;
   int r;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   discrete_type = NULL;
   composite_type = NULL;
@@ -1222,7 +1226,7 @@ static int mailmime_type_parse(const char * message, size_t length,
   }
 
   * result = mime_type;
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMF_NO_ERROR;
 
@@ -1241,14 +1245,14 @@ x  value := token / quoted-string
 
 LIBETPAN_EXPORT
 int mailmime_value_parse(const char * message, size_t length,
-			 size_t * index, char ** result)
+			 size_t * indx, char ** result)
 {
   int r;
 
-  r = mailmime_token_parse(message, length, index, result);
+  r = mailmime_token_parse(message, length, indx, result);
 
   if (r == MAILIMF_ERROR_PARSE)
-    r = mailimf_quoted_string_parse(message, length, index, result);
+    r = mailimf_quoted_string_parse(message, length, indx, result);
 
   if (r != MAILIMF_NO_ERROR)
     return r;
@@ -1262,7 +1266,7 @@ x  version := "MIME-Version" ":" 1*DIGIT "." 1*DIGIT
 
 LIBETPAN_EXPORT
 int mailmime_version_parse(const char * message, size_t length,
-			   size_t * index,
+			   size_t * indx,
 			   uint32_t * result)
 {
   size_t cur_token;
@@ -1271,7 +1275,7 @@ int mailmime_version_parse(const char * message, size_t length,
   uint32_t version;
   int r;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   r = mailimf_number_parse(message, length, &cur_token, &hi);
   if (r != MAILIMF_NO_ERROR)
@@ -1292,7 +1296,7 @@ int mailmime_version_parse(const char * message, size_t length,
   version = (hi << 16) + low;
 
   * result = version;
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMF_NO_ERROR;
 }
@@ -1304,7 +1308,7 @@ x  x-token := <The two characters "X-" or "x-" followed, with
 
 /*
 static gboolean mailmime_x_token_parse(gconst char * message, guint32 length,
-				       guint32 * index,
+				       guint32 * indx,
 				       gchar ** result)
 {
   guint32 cur_token;
@@ -1312,7 +1316,7 @@ static gboolean mailmime_x_token_parse(gconst char * message, guint32 length,
   gchar * x_token;
   gboolean min_x;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   if (!mailimf_char_parse(message, length, &cur_token, 'x')) {
     if (!mailimf_char_parse(message, length, &cur_token, 'X'))
@@ -1338,7 +1342,7 @@ static gboolean mailmime_x_token_parse(gconst char * message, guint32 length,
     return FALSE;
 
   * result = x_token;
-  * index = cur_token;
+  * indx = cur_token;
 
   return TRUE;
 }
@@ -1347,7 +1351,7 @@ static gboolean mailmime_x_token_parse(gconst char * message, guint32 length,
 
 LIBETPAN_EXPORT
 int mailmime_language_parse(const char * message, size_t length,
-			    size_t * index,
+			    size_t * indx,
 			    struct mailmime_language ** result)
 {
   size_t cur_token;
@@ -1357,7 +1361,7 @@ int mailmime_language_parse(const char * message, size_t length,
   int first;
   struct mailmime_language * language;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   list = clist_new();
   if (list == NULL) {
@@ -1409,7 +1413,7 @@ int mailmime_language_parse(const char * message, size_t length,
   }
 
   * result = language;
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMF_NO_ERROR;
 
