@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmime_content.c,v 1.42 2006/12/22 18:45:44 hoa Exp $
+ * $Id: mailmime_content.c,v 1.45 2008/02/20 22:15:52 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -64,7 +64,7 @@
 
 
 static int mailmime_parse_with_default(const char * message, size_t length,
-    size_t * index, int default_type,
+    size_t * indx, int default_type,
     struct mailmime_content * content_type,
     struct mailmime_fields * mime_fields,
     struct mailmime ** result);
@@ -230,12 +230,12 @@ enum {
 };
 
 static int mailmime_preamble_parse(const char * message, size_t length,
-    size_t * index, int beol)
+    size_t * indx, int beol)
 {
   int state;
   size_t cur_token;
 
-  cur_token = * index;
+  cur_token = * indx;
   if (beol)
     state = PREAMBLE_STATE_A0;
   else
@@ -344,18 +344,18 @@ static int mailmime_preamble_parse(const char * message, size_t length,
     cur_token ++;
   }
 
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMF_NO_ERROR;
 }
 
 static int mailmime_boundary_parse(const char * message, size_t length,
-				   size_t * index, char * boundary)
+				   size_t * indx, char * boundary)
 {
   size_t cur_token;
   size_t len;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   len = strlen(boundary);
 
@@ -367,7 +367,7 @@ static int mailmime_boundary_parse(const char * message, size_t length,
 
   cur_token += len;
 
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMF_NO_ERROR;
 }
@@ -381,11 +381,11 @@ static int is_wsp(char ch)
 }
 
 static int mailmime_lwsp_parse(const char * message, size_t length,
-			       size_t * index)
+			       size_t * indx)
 {
   size_t cur_token;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   if (cur_token >= length)
     return MAILIMF_ERROR_PARSE;
@@ -396,16 +396,16 @@ static int mailmime_lwsp_parse(const char * message, size_t length,
       break;
   }
 
-  if (cur_token == * index)
+  if (cur_token == * indx)
     return MAILIMF_ERROR_PARSE;
   
-  * index = cur_token;
+  * indx = cur_token;
   
   return MAILIMF_NO_ERROR;
 }
 
 /*
-gboolean mailimf_crlf_parse(gchar * message, guint32 length, guint32 * index)
+gboolean mailimf_crlf_parse(gchar * message, guint32 length, guint32 * indx)
 */
 
 enum {
@@ -420,7 +420,7 @@ enum {
 
 static int
 mailmime_body_part_dash2_parse(const char * message, size_t length,
-			       size_t * index, char * boundary,
+			       size_t * indx, char * boundary,
 			       const char ** result, size_t * result_size)
 {
   int state;
@@ -430,7 +430,7 @@ mailmime_body_part_dash2_parse(const char * message, size_t length,
   size_t end_text;
   int r;
 
-  cur_token = * index;
+  cur_token = * indx;
   state = BODY_PART_DASH2_STATE_0;
 
   begin_text = cur_token;
@@ -523,13 +523,6 @@ mailmime_body_part_dash2_parse(const char * message, size_t length,
   
   size = end_text - begin_text;
   
-#if 0  
-  if (size > 0) {
-    end_text --;
-    size --;
-  }
-#endif
-
   if (size >= 1) {
     if (message[end_text - 1] == '\r') {
       end_text --;
@@ -553,27 +546,17 @@ mailmime_body_part_dash2_parse(const char * message, size_t length,
   if (size == 0)
     return MAILIMF_ERROR_PARSE;
 
-#if 0
-  body_part = mailimf_body_new(message + begin_text, size);
-  if (body_part == NULL)
-    goto err;
-#endif
-
   * result = message + begin_text;
   * result_size = size;
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMF_NO_ERROR;
-#if 0
- err:
-  return MAILIMF_ERROR_PARSE;
-#endif
 }
 
 static int
 mailmime_body_part_dash2_transport_crlf_parse(const char * message,
     size_t length,
-    size_t * index, char * boundary,
+    size_t * indx, char * boundary,
     const char ** result, size_t * result_size)
 {
   size_t cur_token;
@@ -583,7 +566,7 @@ mailmime_body_part_dash2_transport_crlf_parse(const char * message,
   const char * begin_text;
   const char * end_text;
   
-  cur_token = * index;
+  cur_token = * indx;
   
   begin_text = message + cur_token;
   end_text = message + cur_token;
@@ -624,7 +607,7 @@ mailmime_body_part_dash2_transport_crlf_parse(const char * message,
     }
   }
   
-  * index = cur_token;
+  * indx = cur_token;
   * result = begin_text;
   * result_size = end_text - begin_text;
   
@@ -632,12 +615,12 @@ mailmime_body_part_dash2_transport_crlf_parse(const char * message,
 }
 
 static int mailmime_multipart_close_parse(const char * message, size_t length,
-    size_t * index);
+    size_t * indx);
 
 static int
 mailmime_body_part_dash2_close_parse(const char * message,
     size_t length,
-    size_t * index, char * boundary,
+    size_t * indx, char * boundary,
     const char ** result, size_t * result_size)
 {
   size_t cur_token;
@@ -647,7 +630,7 @@ mailmime_body_part_dash2_close_parse(const char * message,
   const char * begin_text;
   const char * end_text;
   
-  cur_token = * index;
+  cur_token = * indx;
   
   begin_text = message + cur_token;
   end_text = message + cur_token;
@@ -674,9 +657,9 @@ mailmime_body_part_dash2_close_parse(const char * message,
     }
   }
   
-  * index = cur_token;
-  * result = data_str;
-  * result_size = data_size;
+  * indx = cur_token;
+  * result = begin_text;
+  * result_size = end_text - begin_text;
   
   return MAILIMF_NO_ERROR;
 }
@@ -690,12 +673,12 @@ enum {
 };
 
 static int mailmime_multipart_close_parse(const char * message, size_t length,
-    size_t * index)
+    size_t * indx)
 {
   int state;
   size_t cur_token;
 
-  cur_token = * index;
+  cur_token = * indx;
   state = MULTIPART_CLOSE_STATE_0;
 
   while (state != MULTIPART_CLOSE_STATE_4) {
@@ -773,7 +756,7 @@ static int mailmime_multipart_close_parse(const char * message, size_t length,
     cur_token ++;
   }
 
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMF_NO_ERROR;
 }
@@ -786,12 +769,12 @@ enum {
 
 LIBETPAN_EXPORT
 int mailmime_multipart_next_parse(const char * message, size_t length,
-				  size_t * index)
+				  size_t * indx)
 {
   int state;
   size_t cur_token;
 
-  cur_token = * index;
+  cur_token = * indx;
   state = MULTIPART_NEXT_STATE_0;
 
   while (state != MULTIPART_NEXT_STATE_2) {
@@ -834,14 +817,14 @@ int mailmime_multipart_next_parse(const char * message, size_t length,
     cur_token ++;
   }
 
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMF_NO_ERROR;
 }
 
 static int
 mailmime_multipart_body_parse(const char * message, size_t length,
-    size_t * index, char * boundary,
+    size_t * indx, char * boundary,
     int default_subtype,
     clist ** result,
     struct mailmime_data ** p_preamble,
@@ -857,10 +840,6 @@ mailmime_multipart_body_parse(const char * message, size_t length,
   size_t preamble_begin;
   size_t preamble_length;
   size_t preamble_end;
-#if 0
-  int no_preamble;
-  size_t before_crlf;
-#endif
   size_t epilogue_begin;
   size_t epilogue_length;
   struct mailmime_data * preamble;
@@ -871,94 +850,11 @@ mailmime_multipart_body_parse(const char * message, size_t length,
   preamble = NULL;
   epilogue = NULL;
   
-  cur_token = * index;
+  cur_token = * indx;
   preamble_begin = cur_token;
 
-#if 0
-  no_preamble = FALSE;
-#endif
   preamble_end = preamble_begin;
   
-#if 0
-  r = mailmime_preamble_parse(message, length, &cur_token);
-  if (r == MAILIMF_NO_ERROR) {
-    /* do nothing */
-#if 0
-    preamble_end = cur_token - 2;
-#endif
-  }
-  else if (r == MAILIMF_ERROR_PARSE) {
-    /* do nothing */
-    no_preamble = TRUE;
-  }
-  else {
-    res = r;
-    goto err;
-  }
-  
-  while (1) {
-
-    preamble_end = cur_token;
-    r = mailmime_boundary_parse(message, length, &cur_token, boundary);
-    if (r == MAILIMF_NO_ERROR) {
-      break;
-    }
-    else if (r == MAILIMF_ERROR_PARSE) {
-      /* do nothing */
-    }
-    else {
-      res = r;
-      goto err;
-    }
-
-    r = mailmime_preamble_parse(message, length, &cur_token);
-    if (r == MAILIMF_NO_ERROR) {
-#if 0
-      preamble_end = cur_token - 2;
-#endif
-    }
-    else if (r == MAILIMF_ERROR_PARSE) {
-      no_preamble = TRUE;
-      break;
-    }
-    else {
-      res = r;
-      goto err;
-    }
-  }
-  
-  if (no_preamble) {
-#if 0
-    preamble_end = cur_token;
-#endif
-  }
-  else {
-    
-    r = mailmime_lwsp_parse(message, length, &cur_token);
-    if ((r != MAILIMF_NO_ERROR) && (r != MAILIMF_ERROR_PARSE)) {
-      res = r;
-      goto err;
-    }
-    
-    before_crlf = cur_token;
-    r = mailimf_crlf_parse(message, length, &cur_token);
-    if (r == MAILIMF_NO_ERROR) {
-#if 0
-      preamble_end = before_crlf;
-#endif
-      /* remove the CR LF at the end of preamble if any */
-    }
-    else if (r == MAILIMF_ERROR_PARSE) {
-      /* do nothing */
-    }
-    else {
-      res = r;
-      goto err;
-    }
-  }
-  preamble_length = preamble_end - begin;
-#endif
-  
   r = mailmime_preamble_parse(message, length, &cur_token, 1);
   if (r == MAILIMF_NO_ERROR) {
     while (1) {
@@ -1012,10 +908,6 @@ mailmime_multipart_body_parse(const char * message, size_t length,
       res = r;
       goto err;
     }
-#if 0
-    if (r == MAILIMF_ERROR_PARSE)
-      break;
-#endif
     
     r = mailimf_crlf_parse(message, length, &cur_token);
     if (r == MAILIMF_NO_ERROR) {
@@ -1049,60 +941,6 @@ mailmime_multipart_body_parse(const char * message, size_t length,
     struct mailimf_fields * fields;
     struct mailmime_fields * mime_fields;
 
-#if 0    
-    int got_crlf;
-    size_t after_boundary;
-    
-    /* XXX - begin */
-    r = mailmime_body_part_dash2_parse(message, length, &cur_token,
-				       boundary, &data_str, &data_size);
-    if (r == MAILIMF_NO_ERROR) {
-      /* do nothing */
-    }
-    else if (r == MAILIMF_ERROR_PARSE) {
-      break;
-    }
-    else {
-      res = r;
-      goto free;
-    }
-    
-    after_boundary = cur_token;
-    got_crlf = 0;
-    /* parse transport-padding */
-    while (1) {
-      r = mailmime_lwsp_parse(message, length, &cur_token);
-      if ((r != MAILIMF_NO_ERROR) && (r != MAILIMF_ERROR_PARSE)) {
-        res = r;
-        goto free;
-      }
-      
-      r = mailimf_crlf_parse(message, length, &cur_token);
-      if (r == MAILIMF_NO_ERROR) {
-        got_crlf = 1;
-        break;
-      }
-      else if (r == MAILIMF_ERROR_PARSE) {
-        /* do nothing */
-        break;
-      }
-      else {
-        res = r;
-        goto free;
-      }
-    }
-    if (after_boundary != cur_token) {
-      if (!got_crlf) {
-        r = mailimf_crlf_parse(message, length, &cur_token);
-        if (r == MAILIMF_NO_ERROR) {
-          got_crlf = 1;
-          break;
-        }
-      }
-    }
-    /* XXX - end */
-#endif
-
     r = mailmime_body_part_dash2_transport_crlf_parse(message, length,
         &cur_token, boundary, &data_str, &data_size);
     if (r == MAILIMF_ERROR_PARSE) {
@@ -1168,39 +1006,6 @@ mailmime_multipart_body_parse(const char * message, size_t length,
       res = r;
       goto free;
     }
-    
-#if 0
-    else if (r == MAILIMF_ERROR_PARSE) {
-      r = mailmime_body_part_dash2_parse(message, length,
-          &cur_token, boundary, &data_str, &data_size);
-      if (r != MAILIMF_NO_ERROR) {
-        res = r;
-        goto free;
-      }
-      
-      r = mailmime_multipart_close_parse(message, length, &cur_token);
-      if (r == MAILIMF_NO_ERROR) {
-        break;
-      }
-      else if (r == MAILIMF_ERROR_PARSE) {
-        res = r;
-        goto free;
-#if 0
-        fprintf(stderr, "close not found, reparse %s\n", boundary);
-        /* reparse */
-        continue;
-#endif
-      }
-      else {
-        res = r;
-        goto free;
-      }
-    }
-    else {
-      res = r;
-      goto free;
-    }
-#endif
   }
   
   epilogue_begin = length;
@@ -1214,15 +1019,6 @@ mailmime_multipart_body_parse(const char * message, size_t length,
     
     if (r == MAILIMF_ERROR_PARSE)
       break;
-    
-#if 0
-    if (r == MAILIMF_ERROR_PARSE)
-      break;
-#endif
-    
-#if 0
-    before_crlf = cur_token;
-#endif
   }
   
   r = mailimf_crlf_parse(message, length, &cur_token);
@@ -1267,7 +1063,7 @@ mailmime_multipart_body_parse(const char * message, size_t length,
   * result = list;
   * p_preamble = preamble;
   * p_epilogue = epilogue;
-  * index = cur_token;
+  * indx = cur_token;
   
   return MAILIMF_NO_ERROR;
 
@@ -1290,7 +1086,7 @@ enum {
 
 LIBETPAN_EXPORT
 int mailmime_parse(const char * message, size_t length,
-		   size_t * index, struct mailmime ** result)
+		   size_t * indx, struct mailmime ** result)
 {
   struct mailmime * mime;
   int r;
@@ -1302,7 +1098,7 @@ int mailmime_parse(const char * message, size_t length,
   size_t data_size;
   size_t bp_token;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   content_message = mailmime_get_content_message();
   if (content_message == NULL) {
@@ -1344,7 +1140,7 @@ int mailmime_parse(const char * message, size_t length,
     goto free;
   }
   
-  * index = cur_token;
+  * indx = cur_token;
   * result = mime;
 
   return MAILIMF_NO_ERROR;
@@ -1363,6 +1159,8 @@ char * mailmime_extract_boundary(struct mailmime_content * content_type)
 
   boundary = mailmime_content_param_get(content_type, "boundary");
 
+  /* XXX - this should be unquoted properly, should use
+     mailimf_quoted_string_parse() */
   if (boundary != NULL) {
     int len;
     char * new_boundary;
@@ -1434,7 +1232,7 @@ static void remove_unparsed_mime_headers(struct mailimf_fields * fields)
 }
 
 static int mailmime_parse_with_default(const char * message, size_t length,
-    size_t * index, int default_type,
+    size_t * indx, int default_type,
     struct mailmime_content * content_type,
     struct mailmime_fields * mime_fields,
     struct mailmime ** result)
@@ -1465,7 +1263,7 @@ static int mailmime_parse_with_default(const char * message, size_t length,
   preamble = NULL;
   epilogue = NULL;
   
-  cur_token = * index;
+  cur_token = * indx;
 
   /* get content type */
 
@@ -1559,7 +1357,7 @@ static int mailmime_parse_with_default(const char * message, size_t length,
   else
     encoding = MAILMIME_MECHANISM_8BIT;
   
-  cur_token = * index;
+  cur_token = * indx;
   body = mailmime_data_new(MAILMIME_DATA_TEXT, encoding, 1,
       message + cur_token, length - cur_token,
       NULL);
@@ -1631,7 +1429,7 @@ static int mailmime_parse_with_default(const char * message, size_t length,
 	if (strcasecmp(content_type->ct_subtype, "digest") == 0)
 	  default_subtype = MAILMIME_DEFAULT_TYPE_MESSAGE;
 
-      cur_token = * index;
+      cur_token = * indx;
       r = mailmime_multipart_body_parse(message, length,
           &cur_token, boundary,
           default_subtype,
@@ -1671,7 +1469,7 @@ static int mailmime_parse_with_default(const char * message, size_t length,
   }
 
   * result = mime;
-  * index = length;
+  * indx = length;
 
   return MAILIMF_NO_ERROR;
 
@@ -1796,7 +1594,7 @@ static inline signed char get_base64_value(char ch)
 }
 
 int mailmime_base64_body_parse(const char * message, size_t length,
-			       size_t * index, char ** result,
+			       size_t * indx, char ** result,
 			       size_t * result_len)
 {
   size_t cur_token;
@@ -1809,7 +1607,7 @@ int mailmime_base64_body_parse(const char * message, size_t length,
   int r;
   size_t written;
 
-  cur_token = * index;
+  cur_token = * indx;
   chunk_index = 0;
   written = 0;
 
@@ -1884,7 +1682,7 @@ int mailmime_base64_body_parse(const char * message, size_t length,
     goto free;
   }
 
-  * index = cur_token;
+  * indx = cur_token;
   * result = mmapstr->str;
   * result_len = written;
 
@@ -1935,7 +1733,7 @@ static int write_decoded_qp(MMAPString * mmapstr,
 #define WRITE_MAX_QP 512
 
 int mailmime_quoted_printable_body_parse(const char * message, size_t length,
-					 size_t * index, char ** result,
+					 size_t * indx, char ** result,
 					 size_t * result_len, int in_header)
 {
   size_t cur_token;
@@ -1949,7 +1747,7 @@ int mailmime_quoted_printable_body_parse(const char * message, size_t length,
   size_t written;
 
   state = STATE_NORMAL;
-  cur_token = * index;
+  cur_token = * indx;
 
   count = 0;
   start = message + cur_token;
@@ -2221,7 +2019,7 @@ int mailmime_quoted_printable_body_parse(const char * message, size_t length,
     goto free;
   }
 
-  * index = cur_token;
+  * indx = cur_token;
   * result = mmapstr->str;
   * result_len = written;
 
@@ -2234,7 +2032,7 @@ int mailmime_quoted_printable_body_parse(const char * message, size_t length,
 }
 
 int mailmime_binary_body_parse(const char * message, size_t length,
-			       size_t * index, char ** result,
+			       size_t * indx, char ** result,
 			       size_t * result_len)
 {
   MMAPString * mmapstr;
@@ -2242,7 +2040,7 @@ int mailmime_binary_body_parse(const char * message, size_t length,
   int r;
   int res;
 
-  cur_token = * index;
+  cur_token = * indx;
 
 #if 0 /* preserve CR LF at the end of parts */
   if (length >= 1) {
@@ -2267,7 +2065,7 @@ int mailmime_binary_body_parse(const char * message, size_t length,
     goto free;
   }
 
-  * index = length;
+  * indx = length;
   * result = mmapstr->str;
   * result_len = length - cur_token;
 
@@ -2281,23 +2079,23 @@ int mailmime_binary_body_parse(const char * message, size_t length,
 
 
 int mailmime_part_parse(const char * message, size_t length,
-			size_t * index,
+			size_t * indx,
 			int encoding, char ** result, size_t * result_len)
 {
   switch (encoding) {
   case MAILMIME_MECHANISM_BASE64:
-    return mailmime_base64_body_parse(message, length, index,
+    return mailmime_base64_body_parse(message, length, indx,
 				      result, result_len);
     
   case MAILMIME_MECHANISM_QUOTED_PRINTABLE:
-    return mailmime_quoted_printable_body_parse(message, length, index,
+    return mailmime_quoted_printable_body_parse(message, length, indx,
 						result, result_len, FALSE);
 
   case MAILMIME_MECHANISM_7BIT:
   case MAILMIME_MECHANISM_8BIT:
   case MAILMIME_MECHANISM_BINARY:
   default:
-    return mailmime_binary_body_parse(message, length, index,
+    return mailmime_binary_body_parse(message, length, indx,
 				      result, result_len);
   }
 }
