@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmime_decode.c,v 1.32 2007/04/02 23:34:14 hoa Exp $
+ * $Id: mailmime_decode.c,v 1.34 2008/02/20 22:15:52 hoa Exp $
  */
 
 /*
@@ -69,7 +69,7 @@
 #endif
 
 static int mailmime_charset_parse(const char * message, size_t length,
-				  size_t * index, char ** charset);
+				  size_t * indx, char ** charset);
 
 enum {
   MAILMIME_ENCODING_B,
@@ -77,19 +77,19 @@ enum {
 };
 
 static int mailmime_encoding_parse(const char * message, size_t length,
-				   size_t * index, int * result);
+				   size_t * indx, int * result);
 
 static int mailmime_etoken_parse(const char * message, size_t length,
-				 size_t * index, char ** result);
+				 size_t * indx, char ** result);
 
 static int
 mailmime_non_encoded_word_parse(const char * message, size_t length,
-				size_t * index,
+				size_t * indx,
 				char ** result);
 
 static int
 mailmime_encoded_word_parse(const char * message, size_t length,
-			    size_t * index,
+			    size_t * indx,
 			    struct mailmime_encoded_word ** result);
      
 
@@ -102,7 +102,7 @@ enum {
 LIBETPAN_EXPORT
 int mailmime_encoded_phrase_parse(const char * default_fromcode,
     const char * message, size_t length,
-    size_t * index, const char * tocode,
+    size_t * indx, const char * tocode,
     char ** result)
 {
   MMAPString * gphrase;
@@ -115,7 +115,7 @@ int mailmime_encoded_phrase_parse(const char * default_fromcode,
   char * wordutf8;
   int type;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   gphrase = mmap_string_new("");
   if (gphrase == NULL) {
@@ -143,14 +143,8 @@ int mailmime_encoded_phrase_parse(const char * default_fromcode,
       }
       type = TYPE_ENCODED_WORD;
       wordutf8 = NULL;
-      if (strcasecmp(word->wd_charset, "unknown") == 0) {
-        r = charconv(tocode, "iso-8859-1", word->wd_text,
-            strlen(word->wd_text), &wordutf8);
-      }
-      else {
-        r = charconv(tocode, word->wd_charset, word->wd_text,
-            strlen(word->wd_text), &wordutf8);
-      }
+      r = charconv(tocode, word->wd_charset, word->wd_text,
+          strlen(word->wd_text), &wordutf8);
       switch (r) {
       case MAIL_CHARCONV_ERROR_MEMORY:
 	mailmime_encoded_word_free(word);
@@ -158,6 +152,20 @@ int mailmime_encoded_phrase_parse(const char * default_fromcode,
 	goto free;
 
       case MAIL_CHARCONV_ERROR_UNKNOWN_CHARSET:
+        r = charconv(tocode, "iso-8859-1", word->wd_text,
+            strlen(word->wd_text), &wordutf8);
+        break;
+      case MAIL_CHARCONV_ERROR_CONV:
+	mailmime_encoded_word_free(word);
+	res = MAILIMF_ERROR_PARSE;
+	goto free;
+      }
+
+      switch (r) {
+      case MAIL_CHARCONV_ERROR_MEMORY:
+	mailmime_encoded_word_free(word);
+	res = MAILIMF_ERROR_MEMORY;
+	goto free;
       case MAIL_CHARCONV_ERROR_CONV:
 	mailmime_encoded_word_free(word);
 	res = MAILIMF_ERROR_PARSE;
@@ -263,7 +271,7 @@ int mailmime_encoded_phrase_parse(const char * default_fromcode,
   mmap_string_free(gphrase);
 
   * result = str;
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMF_NO_ERROR;
 
@@ -275,7 +283,7 @@ int mailmime_encoded_phrase_parse(const char * default_fromcode,
 
 static int
 mailmime_non_encoded_word_parse(const char * message, size_t length,
-				size_t * index,
+				size_t * indx,
 				char ** result)
 {
   int end;
@@ -285,7 +293,7 @@ mailmime_non_encoded_word_parse(const char * message, size_t length,
   int r;
   size_t begin;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   r = mailimf_fws_parse(message, length, &cur_token);
   if ((r != MAILIMF_NO_ERROR) && (r != MAILIMF_ERROR_PARSE)) {
@@ -329,7 +337,7 @@ mailmime_non_encoded_word_parse(const char * message, size_t length,
   memcpy(text, message + begin, cur_token - begin);
   text[cur_token - begin] = '\0';
 
-  * index = cur_token;
+  * indx = cur_token;
   * result = text;
 
   return MAILIMF_NO_ERROR;
@@ -339,7 +347,7 @@ mailmime_non_encoded_word_parse(const char * message, size_t length,
 }
 
 static int mailmime_encoded_word_parse(const char * message, size_t length,
-				       size_t * index,
+				       size_t * indx,
 				       struct mailmime_encoded_word ** result)
 {
   size_t cur_token;
@@ -355,7 +363,7 @@ static int mailmime_encoded_word_parse(const char * message, size_t length,
   int opening_quote;
   int end;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   r = mailimf_fws_parse(message, length, &cur_token);
   if ((r != MAILIMF_NO_ERROR) && (r != MAILIMF_ERROR_PARSE)) {
@@ -491,7 +499,7 @@ static int mailmime_encoded_word_parse(const char * message, size_t length,
   }
 
   * result = ew;
-  * index = cur_token;
+  * indx = cur_token;
   
   return MAILIMF_NO_ERROR;
 
@@ -504,18 +512,18 @@ static int mailmime_encoded_word_parse(const char * message, size_t length,
 }
 
 static int mailmime_charset_parse(const char * message, size_t length,
-				  size_t * index, char ** charset)
+				  size_t * indx, char ** charset)
 {
-  return mailmime_etoken_parse(message, length, index, charset);
+  return mailmime_etoken_parse(message, length, indx, charset);
 }
 
 static int mailmime_encoding_parse(const char * message, size_t length,
-				   size_t * index, int * result)
+				   size_t * indx, int * result)
 {
   size_t cur_token;
   int encoding;
 
-  cur_token = * index;
+  cur_token = * indx;
 
   if (cur_token >= length)
     return MAILIMF_ERROR_PARSE;
@@ -534,7 +542,7 @@ static int mailmime_encoding_parse(const char * message, size_t length,
   cur_token ++;
 
   * result = encoding;
-  * index = cur_token;
+  * indx = cur_token;
 
   return MAILIMF_NO_ERROR;
 }
@@ -570,9 +578,9 @@ int is_etoken_char(char ch)
 }
 
 static int mailmime_etoken_parse(const char * message, size_t length,
-				 size_t * index, char ** result)
+				 size_t * indx, char ** result)
 {
   return mailimf_custom_string_parse(message, length,
-				     index, result,
+				     indx, result,
 				     is_etoken_char);
 }
