@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailmime_types.c,v 1.19 2005/01/29 15:40:24 hoa Exp $
+ * $Id: mailmime_types.c,v 1.20 2006/06/26 11:50:27 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailmime_types.h"
 #include "mmapstring.h"
 
