@@ -30,21 +30,25 @@
  */
 
 /*
- * $Id: mailmime_write_file.c,v 1.3 2005/06/01 12:22:19 smarinier Exp $
+ * $Id: mailmime_write_file.c,v 1.5 2006/06/26 11:50:27 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailmime_write_file.h"
 
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#if HAVE_SYS_MMAN_H
+#ifdef HAVE_SYS_MMAN_H
 #	include <sys/mman.h>
 #endif
 
