@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmime_write_generic.c,v 1.10 2008/01/14 17:13:53 hoa Exp $
+ * $Id: mailmime_write_generic.c,v 1.11 2008/06/15 11:40:41 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -933,10 +933,23 @@ static int mailmime_part_write_driver(int (* do_write)(void *, const char *, siz
     }
 
     if (build_info->mm_mime_fields != NULL) {
-      r = mailmime_fields_write_driver(do_write, data, col, build_info->mm_mime_fields);
-      if (r != MAILIMF_NO_ERROR) {
-        res = r;
-        goto free_boundary;
+      int r;
+      clistiter * cur;
+      
+      for(cur = clist_begin(build_info->mm_mime_fields->fld_list) ;
+          cur != NULL ;
+          cur = clist_next(cur)) {
+        struct mailmime_field * field;
+        
+        /* only MIME-Version field */
+        field = cur->data;
+        if (field->fld_type == MAILMIME_FIELD_VERSION) {
+          r = mailmime_field_write_driver(do_write, data, col, field);
+          if (r != MAILIMF_NO_ERROR) {
+            res = r;
+            goto free_boundary;
+          }
+        }
       }
     }
 
@@ -990,6 +1003,27 @@ static int mailmime_sub_write_driver(int (* do_write)(void *, const char *, size
         return r;
     }
   }
+  else {
+    if (build_info->mm_mime_fields != NULL) {
+      int r;
+      clistiter * cur;
+      
+      /* filter out MIME-Version */
+      for(cur = clist_begin(build_info->mm_mime_fields->fld_list) ;
+          cur != NULL ;
+      cur = clist_next(cur)) {
+        struct mailmime_field * field;
+        
+        field = cur->data;
+        if (field->fld_type != MAILMIME_FIELD_VERSION) {
+          r = mailmime_field_write_driver(do_write, data, col, field);
+          if (r != MAILIMF_NO_ERROR) {
+            return r;
+          }
+        }
+      }
+    }
+  }
 
   r = mailimf_string_write_driver(do_write, data, col, "\r\n", 2);
   if (r != MAILIMF_NO_ERROR)
