@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: newsnntp.h,v 1.20 2007/06/28 23:24:20 hoa Exp $
+ * $Id: newsnntp.h,v 1.21 2008/02/20 22:15:53 hoa Exp $
  */
 
 #ifndef NEWSNNTP_H
@@ -61,13 +61,13 @@ void newsnntp_free(newsnntp * f);
 int newsnntp_quit(newsnntp * f);
 int newsnntp_connect(newsnntp * f, mailstream * s);
 
-int newsnntp_head(newsnntp * f, uint32_t index,
+int newsnntp_head(newsnntp * f, uint32_t indx,
     char ** result, size_t * result_len);
-int newsnntp_article(newsnntp * f, uint32_t index,
+int newsnntp_article(newsnntp * f, uint32_t indx,
     char ** result, size_t * result_len);
 int newsnntp_article_by_message_id(newsnntp * f, char * msg_id,
     char ** result, size_t * result_len);
-int newsnntp_body(newsnntp * f, uint32_t index,
+int newsnntp_body(newsnntp * f, uint32_t indx,
     char ** result, size_t * result_len);
 
 void newsnntp_head_free(char * str);
