@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: newsnntp_socket.h,v 1.13 2005/06/01 12:22:20 smarinier Exp $
+ * $Id: newsnntp_socket.h,v 1.14 2006/05/22 13:39:42 hoa Exp $
  */
 
 #ifndef NEWSNNTP_SOCKET_H
@@ -42,7 +42,7 @@ extern "C" {
 #endif
 
 #include <sys/types.h>
-#if HAVE_INTTYPES_H
+#ifdef HAVE_INTTYPES_H
 #	include <inttypes.h>
 #endif
 
