@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailpop3_helper.c,v 1.10 2006/06/07 15:10:01 smarinier Exp $
+ * $Id: mailpop3_helper.c,v 1.11 2008/02/20 22:15:53 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -75,8 +75,8 @@ void mailpop3_header_free(char * str)
   mailpop3_top_free(str);
 }
 
-int mailpop3_header(mailpop3 * f, uint32_t index, char ** result,
+int mailpop3_header(mailpop3 * f, uint32_t indx, char ** result,
 		    size_t * result_len)
 {
-  return mailpop3_top(f, index, 0, result, result_len);
+  return mailpop3_top(f, indx, 0, result, result_len);
 }
