@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailpop3_socket.c,v 1.15 2007/10/27 10:08:26 hoa Exp $
+ * $Id: mailpop3_socket.c,v 1.16 2009/12/19 00:57:31 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -73,7 +73,11 @@ int mailpop3_socket_connect(mailpop3 * f, const char * server, uint16_t port)
 
   stream = mailstream_socket_open(s);
   if (stream == NULL) {
+#ifdef WIN32
+	closesocket(s);
+#else
     close(s);
+#endif
     return MAILPOP3_ERROR_MEMORY;
   }
 
