@@ -32,7 +32,7 @@
  */
 
 /*
- * $Id: mailsmtp.c,v 1.32 2007/10/27 10:08:26 hoa Exp $
+ * $Id: mailsmtp.c,v 1.34 2010/04/05 14:21:36 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -624,6 +624,8 @@ int auth_map_errors(int err)
     return MAILSMTP_ERROR_AUTH_TRANSITION_NEEDED;
   case 454:
     return MAILSMTP_ERROR_AUTH_TEMPORARY_FAILTURE;
+  case 501:
+    return MAILSMTP_ERROR_AUTH_LOGIN;
   case 504:
     return MAILSMTP_ERROR_AUTH_NOT_SUPPORTED;
   case 530:
@@ -695,7 +697,6 @@ int mailsmtp_auth_type(mailsmtp * session,
     const char * user, const char * pass, int type)
 {
   int err;
-  char command[SMTP_STRING_SIZE];
   char hostname[SMTP_STRING_SIZE];
   
   err = gethostname(hostname, sizeof(hostname));
@@ -710,19 +711,6 @@ int mailsmtp_auth_type(mailsmtp * session,
   
   switch (type) {
   case MAILSMTP_AUTH_LOGIN:
-#if 0
-    {
-      snprintf(command, SMTP_STRING_SIZE, "AUTH LOGIN\r\n");
-      err = send_command(session, command);
-      if (err == -1) return MAILSMTP_ERROR_STREAM;
-      
-      err = read_response(session);
-      err = auth_map_errors(err);
-      if (err != MAILSMTP_NO_ERROR) return err;
-      
-      return mailsmtp_auth_login(session, user, pass);
-    }
-#endif
     return mailesmtp_auth_sasl(session, "LOGIN",
         hostname, NULL, NULL, user, user, pass, NULL);
     
