@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailsmtp_ssl.c,v 1.14 2006/06/26 11:50:28 hoa Exp $
+ * $Id: mailsmtp_ssl.c,v 1.16 2006/12/26 13:13:25 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -57,6 +57,14 @@
 
 int mailsmtp_ssl_connect(mailsmtp * session,
     const char * server, uint16_t port)
+{
+  return mailsmtp_ssl_connect_with_callback(session, server, port,
+      NULL, NULL);
+}
+
+int mailsmtp_ssl_connect_with_callback(mailsmtp * session,
+    const char * server, uint16_t port,
+    void (* callback)(struct mailstream_ssl_context * ssl_context, void * data), void * data)
 {
   int s;
   mailstream * stream;
@@ -76,7 +84,7 @@ int mailsmtp_ssl_connect(mailsmtp * session,
   stream = mailstream_ssl_open(s);
   if (stream == NULL) {
     close(s);
-    return MAILSMTP_ERROR_CONNECTION_REFUSED;
+    return MAILSMTP_ERROR_SSL;
   }
 
   return mailsmtp_connect(session, stream);
