@@ -1,3 +1,7 @@
+/* This file is included for compilation to Windows targets, native as
+   well as mingw32.  In native compilation, _MSC_VER is defined.  In
+   mingw32 compilation, HAVE_MINGW32_SYSTEM is defined.  Both define WIN32. */
+
 /* MS C++ Compiler includes */
 #ifndef __win_etpan_h
 #define __win_etpan_h
@@ -6,23 +10,31 @@
 #include <process.h>
 #include <stdlib.h>
 #include <errno.h>
+#ifdef HAVE_MINGW32_SYSTEM
+#include <time.h>
+#include <dirent.h>
+#include <winsock2.h>
+#define EINPROGRESS WSAEINPROGRESS
+#endif
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-/* for compatibility */
-#define S_IRUSR		_S_IREAD
-#define S_IWUSR		_S_IWRITE
-
 /* compatibility is allowed with MULTITHREAD DLL */
 extern struct tm *gmtime_r (const time_t *timep, struct tm *result);
 extern struct tm *localtime_r (const time_t *timep, struct tm *result);
 
+#ifndef HAVE_MINGW32_SYSTEM
+/* for compatibility */
+#define S_IRUSR		_S_IREAD
+#define S_IWUSR		_S_IWRITE
+
 /* stat */
 typedef unsigned short mode_t;
 #define S_ISREG(x) ((x &  _S_IFMT) == _S_IFREG)
 #define S_ISDIR(x) ((x &  _S_IFMT) == _S_IFDIR)
+#endif
 
 /* same properties ? */
 #define random() rand()
@@ -38,6 +50,7 @@ extern int mkstemp (char *tmp_template);
 
 #define link(x, y) (errno = EPERM)
 
+#ifndef HAVE_MINGW32_SYSTEM
 /* ------------------------------------------------- */
 /* dirent */
 
@@ -66,6 +79,7 @@ extern int closedir (DIR *__dirp);
    same DIR stream.*/
 extern struct dirent *readdir (DIR *__dirp);
 /* ------------------------------------------------- */
+#endif
 
 /* ------------------------------------------------- */
 /* sys/mman */
